Class ApplicationsRequestBuilder

java.lang.Object
com.microsoft.kiota.BaseRequestBuilder
com.microsoft.graph.applications.ApplicationsRequestBuilder

@Generated("com.microsoft.kiota") public class ApplicationsRequestBuilder extends com.microsoft.kiota.BaseRequestBuilder
Provides operations to manage the collection of application entities.
  • Constructor Details

    • ApplicationsRequestBuilder

      public ApplicationsRequestBuilder(@Nonnull HashMap<String,Object> pathParameters, @Nonnull com.microsoft.kiota.RequestAdapter requestAdapter)
      Instantiates a new ApplicationsRequestBuilder and sets the default values.
      Parameters:
      pathParameters - Path parameters for the request
      requestAdapter - The request adapter to use to execute the requests.
    • ApplicationsRequestBuilder

      public ApplicationsRequestBuilder(@Nonnull String rawUrl, @Nonnull com.microsoft.kiota.RequestAdapter requestAdapter)
      Instantiates a new ApplicationsRequestBuilder and sets the default values.
      Parameters:
      rawUrl - The raw URL to use for the request builder.
      requestAdapter - The request adapter to use to execute the requests.
  • Method Details

    • count

      @Nonnull public CountRequestBuilder count()
      Provides operations to count the resources in the collection.
      Returns:
      a CountRequestBuilder
    • delta

      @Nonnull public DeltaRequestBuilder delta()
      Provides operations to call the delta method.
      Returns:
      a DeltaRequestBuilder
    • getAvailableExtensionProperties

      @Nonnull public GetAvailableExtensionPropertiesRequestBuilder getAvailableExtensionProperties()
      Provides operations to call the getAvailableExtensionProperties method.
      Returns:
      a GetAvailableExtensionPropertiesRequestBuilder
    • getByIds

      @Nonnull public GetByIdsRequestBuilder getByIds()
      Provides operations to call the getByIds method.
      Returns:
      a GetByIdsRequestBuilder
    • validateProperties

      @Nonnull public ValidatePropertiesRequestBuilder validateProperties()
      Provides operations to call the validateProperties method.
      Returns:
      a ValidatePropertiesRequestBuilder
    • byApplicationId

      @Nonnull public ApplicationItemRequestBuilder byApplicationId(@Nonnull String applicationId)
      Provides operations to manage the collection of application entities.
      Parameters:
      applicationId - The unique identifier of application
      Returns:
      a ApplicationItemRequestBuilder
    • get

      @Nullable public ApplicationCollectionResponse get()
      Get the list of applications in this organization. This API also returns agentIdentityBlueprint objects, which are identified by the @odata.type property of #microsoft.graph.agentIdentityBlueprint.
      Returns:
      a ApplicationCollectionResponse
      Throws:
      ODataError - When receiving a 4XX or 5XX status code
      See Also:
    • get

      @Nullable public ApplicationCollectionResponse get(@Nullable Consumer<ApplicationsRequestBuilder.GetRequestConfiguration> requestConfiguration)
      Get the list of applications in this organization. This API also returns agentIdentityBlueprint objects, which are identified by the @odata.type property of #microsoft.graph.agentIdentityBlueprint.
      Parameters:
      requestConfiguration - Configuration for the request such as headers, query parameters, and middleware options.
      Returns:
      a ApplicationCollectionResponse
      Throws:
      ODataError - When receiving a 4XX or 5XX status code
      See Also:
    • post

      @Nullable public Application post(@Nonnull Application body)
      Create a new application object. This API can also create an agentIdentityBlueprint object when the @odata.type property is set to #microsoft.graph.agentIdentityBlueprint.
      Parameters:
      body - The request body
      Returns:
      a Application
      Throws:
      ODataError - When receiving a 4XX or 5XX status code
      See Also:
    • post

      @Nullable public Application post(@Nonnull Application body, @Nullable Consumer<ApplicationsRequestBuilder.PostRequestConfiguration> requestConfiguration)
      Create a new application object. This API can also create an agentIdentityBlueprint object when the @odata.type property is set to #microsoft.graph.agentIdentityBlueprint.
      Parameters:
      body - The request body
      requestConfiguration - Configuration for the request such as headers, query parameters, and middleware options.
      Returns:
      a Application
      Throws:
      ODataError - When receiving a 4XX or 5XX status code
      See Also:
    • toGetRequestInformation

      @Nonnull public com.microsoft.kiota.RequestInformation toGetRequestInformation()
      Get the list of applications in this organization. This API also returns agentIdentityBlueprint objects, which are identified by the @odata.type property of #microsoft.graph.agentIdentityBlueprint.
      Returns:
      a RequestInformation
    • toGetRequestInformation

      @Nonnull public com.microsoft.kiota.RequestInformation toGetRequestInformation(@Nullable Consumer<ApplicationsRequestBuilder.GetRequestConfiguration> requestConfiguration)
      Get the list of applications in this organization. This API also returns agentIdentityBlueprint objects, which are identified by the @odata.type property of #microsoft.graph.agentIdentityBlueprint.
      Parameters:
      requestConfiguration - Configuration for the request such as headers, query parameters, and middleware options.
      Returns:
      a RequestInformation
    • toPostRequestInformation

      @Nonnull public com.microsoft.kiota.RequestInformation toPostRequestInformation(@Nonnull Application body)
      Create a new application object. This API can also create an agentIdentityBlueprint object when the @odata.type property is set to #microsoft.graph.agentIdentityBlueprint.
      Parameters:
      body - The request body
      Returns:
      a RequestInformation
    • toPostRequestInformation

      @Nonnull public com.microsoft.kiota.RequestInformation toPostRequestInformation(@Nonnull Application body, @Nullable Consumer<ApplicationsRequestBuilder.PostRequestConfiguration> requestConfiguration)
      Create a new application object. This API can also create an agentIdentityBlueprint object when the @odata.type property is set to #microsoft.graph.agentIdentityBlueprint.
      Parameters:
      body - The request body
      requestConfiguration - Configuration for the request such as headers, query parameters, and middleware options.
      Returns:
      a RequestInformation
    • withUrl

      @Nonnull public ApplicationsRequestBuilder withUrl(@Nonnull String rawUrl)
      Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
      Parameters:
      rawUrl - The raw URL to use for the request builder.
      Returns:
      a ApplicationsRequestBuilder