Package com.microsoft.graph.models
Class Admin
java.lang.Object
com.microsoft.graph.models.Admin
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class Admin
extends Object
implements com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.store.BackedModel, com.microsoft.kiota.serialization.Parsable
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected com.microsoft.kiota.store.BackingStoreStores model information. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic AdmincreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the AdditionalData property value.com.microsoft.kiota.store.BackingStoreGets the backingStore property value.Gets the configurationManagement property value.getEdge()Gets the edge property value.Gets the exchange property value.The deserialization information for the current modelGets the microsoft365Apps property value.Gets the @odata.type property value.Gets the people property value.Gets the reportSettings property value.Gets the serviceAnnouncement property value.Gets the sharepoint property value.getTeams()Gets the teams property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetAdditionalData(Map<String, Object> value) Sets the AdditionalData property value.voidsetBackingStore(com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value.voidSets the configurationManagement property value.voidSets the edge property value.voidsetExchange(ExchangeAdmin value) Sets the exchange property value.voidSets the microsoft365Apps property value.voidsetOdataType(String value) Sets the @odata.type property value.voidsetPeople(PeopleAdminSettings value) Sets the people property value.voidSets the reportSettings property value.voidSets the serviceAnnouncement property value.voidsetSharepoint(Sharepoint value) Sets the sharepoint property value.voidsetTeams(TeamsAdminRoot value) Sets the teams property value.
-
Field Details
-
backingStore
@Nonnull protected com.microsoft.kiota.store.BackingStore backingStoreStores model information.
-
-
Constructor Details
-
Admin
public Admin()Instantiates a newAdminand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static Admin createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
Admin
-
getAdditionalData
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. -
getBackingStore
@Nonnull public com.microsoft.kiota.store.BackingStore getBackingStore()Gets the backingStore property value. Stores model information.- Specified by:
getBackingStorein interfacecom.microsoft.kiota.store.BackedModel- Returns:
- a
BackingStore
-
getConfigurationManagement
Gets the configurationManagement property value. A container for Tenant Configuration Management (TCM) resources. Read-only.- Returns:
- a
ConfigurationManagement
-
getEdge
Gets the edge property value. A container for Microsoft Edge resources. Read-only.- Returns:
- a
Edge
-
getExchange
Gets the exchange property value. A container for the Exchange admin functionality. Read-only.- Returns:
- a
ExchangeAdmin
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model -
getMicrosoft365Apps
Gets the microsoft365Apps property value. A container for the Microsoft 365 apps admin functionality.- Returns:
- a
AdminMicrosoft365Apps
-
getOdataType
Gets the @odata.type property value. The OdataType property- Returns:
- a
String
-
getPeople
Gets the people property value. Represents a setting to control people-related admin settings in the tenant.- Returns:
- a
PeopleAdminSettings
-
getReportSettings
Gets the reportSettings property value. A container for administrative resources to manage reports.- Returns:
- a
AdminReportSettings
-
getServiceAnnouncement
Gets the serviceAnnouncement property value. A container for service communications resources. Read-only.- Returns:
- a
ServiceAnnouncement
-
getTeams
Gets the teams property value. A container for Teams administration functionalities, such as Teams telephone number management functionalities, user Teams configurations, and policy assignments.- Returns:
- a
TeamsAdminRoot
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Parameters:
writer- Serialization writer to use to serialize this model
-
setAdditionalData
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.- Parameters:
value- Value to set for the AdditionalData property.
-
setBackingStore
public void setBackingStore(@Nonnull com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value. Stores model information.- Parameters:
value- Value to set for the backingStore property.
-
setConfigurationManagement
Sets the configurationManagement property value. A container for Tenant Configuration Management (TCM) resources. Read-only.- Parameters:
value- Value to set for the configurationManagement property.
-
setEdge
Sets the edge property value. A container for Microsoft Edge resources. Read-only.- Parameters:
value- Value to set for the edge property.
-
setExchange
Sets the exchange property value. A container for the Exchange admin functionality. Read-only.- Parameters:
value- Value to set for the exchange property.
-
setMicrosoft365Apps
Sets the microsoft365Apps property value. A container for the Microsoft 365 apps admin functionality.- Parameters:
value- Value to set for the microsoft365Apps property.
-
setOdataType
Sets the @odata.type property value. The OdataType property- Parameters:
value- Value to set for the @odata.type property.
-
setPeople
Sets the people property value. Represents a setting to control people-related admin settings in the tenant.- Parameters:
value- Value to set for the people property.
-
setReportSettings
Sets the reportSettings property value. A container for administrative resources to manage reports.- Parameters:
value- Value to set for the reportSettings property.
-
setServiceAnnouncement
Sets the serviceAnnouncement property value. A container for service communications resources. Read-only.- Parameters:
value- Value to set for the serviceAnnouncement property.
-
setTeams
Sets the teams property value. A container for Teams administration functionalities, such as Teams telephone number management functionalities, user Teams configurations, and policy assignments.- Parameters:
value- Value to set for the teams property.
-