Package com.microsoft.graph.models
Class AgentUser
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.DirectoryObject
com.microsoft.graph.models.User
com.microsoft.graph.models.AgentUser
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class AgentUser
extends User
implements com.microsoft.kiota.serialization.Parsable
Represents a Microsoft Entra user account.
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic AgentUsercreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueThe deserialization information for the current modelvoidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectMethods inherited from class com.microsoft.graph.models.User
getAboutMe, getAccountEnabled, getActivities, getAdhocCalls, getAgeGroup, getAgreementAcceptances, getAppRoleAssignments, getAssignedLicenses, getAssignedPlans, getAuthentication, getAuthorizationInfo, getBirthday, getBusinessPhones, getCalendar, getCalendarGroups, getCalendars, getCalendarView, getChats, getCity, getCloudClipboard, getCloudPCs, getCompanyName, getConsentProvidedForMinor, getContactFolders, getContacts, getCountry, getCreatedDateTime, getCreatedObjects, getCreationType, getCustomSecurityAttributes, getDataSecurityAndGovernance, getDepartment, getDeviceEnrollmentLimit, getDeviceManagementTroubleshootingEvents, getDirectReports, getDisplayName, getDrive, getDrives, getEmployeeExperience, getEmployeeHireDate, getEmployeeId, getEmployeeLeaveDateTime, getEmployeeOrgData, getEmployeeType, getEvents, getExtensions, getExternalUserState, getExternalUserStateChangeDateTime, getFaxNumber, getFollowedSites, getGivenName, getHireDate, getIdentities, getIdentityParentId, getImAddresses, getInferenceClassification, getInsights, getInterests, getIsManagementRestricted, getIsResourceAccount, getJobTitle, getJoinedTeams, getLastPasswordChangeDateTime, getLegalAgeGroupClassification, getLicenseAssignmentStates, getLicenseDetails, getMail, getMailboxSettings, getMailFolders, getMailNickname, getManagedAppRegistrations, getManagedDevices, getManager, getMemberOf, getMessages, getMobilePhone, getMySite, getOauth2PermissionGrants, getOfficeLocation, getOnenote, getOnlineMeetings, getOnPremisesDistinguishedName, getOnPremisesDomainName, getOnPremisesExtensionAttributes, getOnPremisesImmutableId, getOnPremisesLastSyncDateTime, getOnPremisesProvisioningErrors, getOnPremisesSamAccountName, getOnPremisesSecurityIdentifier, getOnPremisesSyncBehavior, getOnPremisesSyncEnabled, getOnPremisesUserPrincipalName, getOtherMails, getOutlook, getOwnedDevices, getOwnedObjects, getPasswordPolicies, getPasswordProfile, getPastProjects, getPeople, getPermissionGrants, getPhoto, getPhotos, getPlanner, getPostalCode, getPreferredDataLocation, getPreferredLanguage, getPreferredName, getPresence, getPrint, getProvisionedPlans, getProxyAddresses, getRegisteredDevices, getResponsibilities, getSchools, getScopedRoleMemberOf, getSecurityIdentifier, getServiceProvisioningErrors, getSettings, getShowInAddressList, getSignInActivity, getSignInSessionsValidFromDateTime, getSkills, getSolutions, getSponsors, getState, getStreetAddress, getSurname, getTeamwork, getTodo, getTransitiveMemberOf, getUsageLocation, getUserPrincipalName, getUserType, setAboutMe, setAccountEnabled, setActivities, setAdhocCalls, setAgeGroup, setAgreementAcceptances, setAppRoleAssignments, setAssignedLicenses, setAssignedPlans, setAuthentication, setAuthorizationInfo, setBirthday, setBusinessPhones, setCalendar, setCalendarGroups, setCalendars, setCalendarView, setChats, setCity, setCloudClipboard, setCloudPCs, setCompanyName, setConsentProvidedForMinor, setContactFolders, setContacts, setCountry, setCreatedDateTime, setCreatedObjects, setCreationType, setCustomSecurityAttributes, setDataSecurityAndGovernance, setDepartment, setDeviceEnrollmentLimit, setDeviceManagementTroubleshootingEvents, setDirectReports, setDisplayName, setDrive, setDrives, setEmployeeExperience, setEmployeeHireDate, setEmployeeId, setEmployeeLeaveDateTime, setEmployeeOrgData, setEmployeeType, setEvents, setExtensions, setExternalUserState, setExternalUserStateChangeDateTime, setFaxNumber, setFollowedSites, setGivenName, setHireDate, setIdentities, setIdentityParentId, setImAddresses, setInferenceClassification, setInsights, setInterests, setIsManagementRestricted, setIsResourceAccount, setJobTitle, setJoinedTeams, setLastPasswordChangeDateTime, setLegalAgeGroupClassification, setLicenseAssignmentStates, setLicenseDetails, setMail, setMailboxSettings, setMailFolders, setMailNickname, setManagedAppRegistrations, setManagedDevices, setManager, setMemberOf, setMessages, setMobilePhone, setMySite, setOauth2PermissionGrants, setOfficeLocation, setOnenote, setOnlineMeetings, setOnPremisesDistinguishedName, setOnPremisesDomainName, setOnPremisesExtensionAttributes, setOnPremisesImmutableId, setOnPremisesLastSyncDateTime, setOnPremisesProvisioningErrors, setOnPremisesSamAccountName, setOnPremisesSecurityIdentifier, setOnPremisesSyncBehavior, setOnPremisesSyncEnabled, setOnPremisesUserPrincipalName, setOtherMails, setOutlook, setOwnedDevices, setOwnedObjects, setPasswordPolicies, setPasswordProfile, setPastProjects, setPeople, setPermissionGrants, setPhoto, setPhotos, setPlanner, setPostalCode, setPreferredDataLocation, setPreferredLanguage, setPreferredName, setPresence, setPrint, setProvisionedPlans, setProxyAddresses, setRegisteredDevices, setResponsibilities, setSchools, setScopedRoleMemberOf, setSecurityIdentifier, setServiceProvisioningErrors, setSettings, setShowInAddressList, setSignInActivity, setSignInSessionsValidFromDateTime, setSkills, setSolutions, setSponsors, setState, setStreetAddress, setSurname, setTeamwork, setTodo, setTransitiveMemberOf, setUsageLocation, setUserPrincipalName, setUserTypeMethods inherited from class com.microsoft.graph.models.DirectoryObject
getDeletedDateTime, setDeletedDateTimeMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
AgentUser
public AgentUser()Instantiates a newAgentUserand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static AgentUser createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
AgentUser
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classUser- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object
-