Class ConfigurationBaseline

java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ConfigurationBaseline
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class ConfigurationBaseline extends Entity implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • ConfigurationBaseline

      public ConfigurationBaseline()
      Instantiates a new ConfigurationBaseline and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static ConfigurationBaseline createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a ConfigurationBaseline
    • getDescription

      @Nullable public String getDescription()
      Gets the description property value. User-friendly description of the baseline given by the user.
      Returns:
      a String
    • getDisplayName

      @Nullable public String getDisplayName()
      Gets the displayName property value. User-friendly name given by the user to the baseline.
      Returns:
      a String
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class Entity
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getParameters

      @Nullable public List<BaselineParameter> getParameters()
      Gets the parameters property value. Collection of parameters attached to the baseline.
      Returns:
      a List<BaselineParameter>
    • getResources

      @Nullable public List<BaselineResource> getResources()
      Gets the resources property value. Collection of resources and their properties that are added to the baseline. At least one property of one resource must be present in the baseline.
      Returns:
      a List<BaselineResource>
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class Entity
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setDescription

      public void setDescription(@Nullable String value)
      Sets the description property value. User-friendly description of the baseline given by the user.
      Parameters:
      value - Value to set for the description property.
    • setDisplayName

      public void setDisplayName(@Nullable String value)
      Sets the displayName property value. User-friendly name given by the user to the baseline.
      Parameters:
      value - Value to set for the displayName property.
    • setParameters

      public void setParameters(@Nullable List<BaselineParameter> value)
      Sets the parameters property value. Collection of parameters attached to the baseline.
      Parameters:
      value - Value to set for the parameters property.
    • setResources

      public void setResources(@Nullable List<BaselineResource> value)
      Sets the resources property value. Collection of resources and their properties that are added to the baseline. At least one property of one resource must be present in the baseline.
      Parameters:
      value - Value to set for the resources property.