Package com.microsoft.graph.models
Class ConfigurationManagement
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ConfigurationManagement
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ConfigurationManagement
extends Entity
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ConfigurationManagementcreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the configurationDrifts property value.Gets the configurationMonitoringResults property value.Gets the configurationMonitors property value.Gets the configurationSnapshotJobs property value.Gets the configurationSnapshots property value.The deserialization information for the current modelvoidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidSets the configurationDrifts property value.voidSets the configurationMonitoringResults property value.voidSets the configurationMonitors property value.voidSets the configurationSnapshotJobs property value.voidSets the configurationSnapshots property value.Methods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
ConfigurationManagement
public ConfigurationManagement()Instantiates a newConfigurationManagementand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ConfigurationManagement createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ConfigurationManagement
-
getConfigurationDrifts
Gets the configurationDrifts property value. A container for configuration drift resources.- Returns:
- a
List<ConfigurationDrift>
-
getConfigurationMonitoringResults
Gets the configurationMonitoringResults property value. A container for configuration monitoring results resources.- Returns:
- a
List<ConfigurationMonitoringResult>
-
getConfigurationMonitors
Gets the configurationMonitors property value. A container for configuration monitor resources.- Returns:
- a
List<ConfigurationMonitor>
-
getConfigurationSnapshotJobs
Gets the configurationSnapshotJobs property value. A container for snapshot job resources.- Returns:
- a
List<ConfigurationSnapshotJob>
-
getConfigurationSnapshots
Gets the configurationSnapshots property value. A container for configuration snapshot baselines.- Returns:
- a
List<ConfigurationBaseline>
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classEntity- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object -
setConfigurationDrifts
Sets the configurationDrifts property value. A container for configuration drift resources.- Parameters:
value- Value to set for the configurationDrifts property.
-
setConfigurationMonitoringResults
Sets the configurationMonitoringResults property value. A container for configuration monitoring results resources.- Parameters:
value- Value to set for the configurationMonitoringResults property.
-
setConfigurationMonitors
Sets the configurationMonitors property value. A container for configuration monitor resources.- Parameters:
value- Value to set for the configurationMonitors property.
-
setConfigurationSnapshotJobs
Sets the configurationSnapshotJobs property value. A container for snapshot job resources.- Parameters:
value- Value to set for the configurationSnapshotJobs property.
-
setConfigurationSnapshots
Sets the configurationSnapshots property value. A container for configuration snapshot baselines.- Parameters:
value- Value to set for the configurationSnapshots property.
-