Class ConfigurationMonitor

java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ConfigurationMonitor
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class ConfigurationMonitor extends Entity implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • ConfigurationMonitor

      public ConfigurationMonitor()
      Instantiates a new ConfigurationMonitor and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static ConfigurationMonitor createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a ConfigurationMonitor
    • getBaseline

      @Nullable public ConfigurationBaseline getBaseline()
      Gets the baseline property value. The baseline property
      Returns:
      a ConfigurationBaseline
    • getCreatedBy

      @Nullable public IdentitySet getCreatedBy()
      Gets the createdBy property value. The createdBy property
      Returns:
      a IdentitySet
    • getCreatedDateTime

      @Nullable public OffsetDateTime getCreatedDateTime()
      Gets the createdDateTime property value. The date and time when the monitor was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Returns:
      a OffsetDateTime
    • getDescription

      @Nullable public String getDescription()
      Gets the description property value. User-friendly description of the monitor given by the user. Supports $filter (eq, ne, startsWith) and $orderby.
      Returns:
      a String
    • getDisplayName

      @Nullable public String getDisplayName()
      Gets the displayName property value. User-friendly name given by the user to the monitor. Supports $filter (eq, ne, startsWith) and $orderby.
      Returns:
      a String
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class Entity
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getInactivationReason

      @Nullable public String getInactivationReason()
      Gets the inactivationReason property value. The reason for the monitor's inactivation. Requires $select to retrieve.
      Returns:
      a String
    • getLastModifiedBy

      @Nullable public IdentitySet getLastModifiedBy()
      Gets the lastModifiedBy property value. The lastModifiedBy property
      Returns:
      a IdentitySet
    • getLastModifiedDateTime

      @Nullable public OffsetDateTime getLastModifiedDateTime()
      Gets the lastModifiedDateTime property value. The date and time when the monitor was last modified. If no modifications are made to the monitor, it's the same as createdDateTime. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Returns:
      a OffsetDateTime
    • getMode

      @Nullable public MonitorMode getMode()
      Gets the mode property value. The mode property
      Returns:
      a MonitorMode
    • getMonitorRunFrequencyInHours

      @Nullable public Integer getMonitorRunFrequencyInHours()
      Gets the monitorRunFrequencyInHours property value. Frequency at which the monitor runs. The default frequency is six hours. Regardless of when you create or update a monitor, it gets triggered within the next 6 hours. Currently, monitors are picked up at fixed times: 6 AM, 12 PM, 6 PM, and 12 AM (all in GMT). For example, if you create a monitor at 9 AM, it gets triggered around 12 PM. If you update a monitor at 4 PM, it gets triggered around 6 PM.
      Returns:
      a Integer
    • getParameters

      @Nullable public OpenComplexDictionaryType getParameters()
      Gets the parameters property value. Key-value pairs that contain parameter values which might be used in the baseline. Requires $select to retrieve.
      Returns:
      a OpenComplexDictionaryType
    • getStatus

      @Nullable public MonitorStatus getStatus()
      Gets the status property value. The status property
      Returns:
      a MonitorStatus
    • getTenantId

      @Nullable public String getTenantId()
      Gets the tenantId property value. Globally unique identifier (GUID) of the tenant for which the monitor runs. Fetched automatically by the system. Supports $filter (eq, ne).
      Returns:
      a String
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class Entity
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setBaseline

      public void setBaseline(@Nullable ConfigurationBaseline value)
      Sets the baseline property value. The baseline property
      Parameters:
      value - Value to set for the baseline property.
    • setCreatedBy

      public void setCreatedBy(@Nullable IdentitySet value)
      Sets the createdBy property value. The createdBy property
      Parameters:
      value - Value to set for the createdBy property.
    • setCreatedDateTime

      public void setCreatedDateTime(@Nullable OffsetDateTime value)
      Sets the createdDateTime property value. The date and time when the monitor was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Parameters:
      value - Value to set for the createdDateTime property.
    • setDescription

      public void setDescription(@Nullable String value)
      Sets the description property value. User-friendly description of the monitor given by the user. Supports $filter (eq, ne, startsWith) and $orderby.
      Parameters:
      value - Value to set for the description property.
    • setDisplayName

      public void setDisplayName(@Nullable String value)
      Sets the displayName property value. User-friendly name given by the user to the monitor. Supports $filter (eq, ne, startsWith) and $orderby.
      Parameters:
      value - Value to set for the displayName property.
    • setInactivationReason

      public void setInactivationReason(@Nullable String value)
      Sets the inactivationReason property value. The reason for the monitor's inactivation. Requires $select to retrieve.
      Parameters:
      value - Value to set for the inactivationReason property.
    • setLastModifiedBy

      public void setLastModifiedBy(@Nullable IdentitySet value)
      Sets the lastModifiedBy property value. The lastModifiedBy property
      Parameters:
      value - Value to set for the lastModifiedBy property.
    • setLastModifiedDateTime

      public void setLastModifiedDateTime(@Nullable OffsetDateTime value)
      Sets the lastModifiedDateTime property value. The date and time when the monitor was last modified. If no modifications are made to the monitor, it's the same as createdDateTime. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Parameters:
      value - Value to set for the lastModifiedDateTime property.
    • setMode

      public void setMode(@Nullable MonitorMode value)
      Sets the mode property value. The mode property
      Parameters:
      value - Value to set for the mode property.
    • setMonitorRunFrequencyInHours

      public void setMonitorRunFrequencyInHours(@Nullable Integer value)
      Sets the monitorRunFrequencyInHours property value. Frequency at which the monitor runs. The default frequency is six hours. Regardless of when you create or update a monitor, it gets triggered within the next 6 hours. Currently, monitors are picked up at fixed times: 6 AM, 12 PM, 6 PM, and 12 AM (all in GMT). For example, if you create a monitor at 9 AM, it gets triggered around 12 PM. If you update a monitor at 4 PM, it gets triggered around 6 PM.
      Parameters:
      value - Value to set for the monitorRunFrequencyInHours property.
    • setParameters

      public void setParameters(@Nullable OpenComplexDictionaryType value)
      Sets the parameters property value. Key-value pairs that contain parameter values which might be used in the baseline. Requires $select to retrieve.
      Parameters:
      value - Value to set for the parameters property.
    • setStatus

      public void setStatus(@Nullable MonitorStatus value)
      Sets the status property value. The status property
      Parameters:
      value - Value to set for the status property.
    • setTenantId

      public void setTenantId(@Nullable String value)
      Sets the tenantId property value. Globally unique identifier (GUID) of the tenant for which the monitor runs. Fetched automatically by the system. Supports $filter (eq, ne).
      Parameters:
      value - Value to set for the tenantId property.