Class ConfigurationMonitoringResult

java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ConfigurationMonitoringResult
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class ConfigurationMonitoringResult extends Entity implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • ConfigurationMonitoringResult

      public ConfigurationMonitoringResult()
      Instantiates a new ConfigurationMonitoringResult and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static ConfigurationMonitoringResult createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a ConfigurationMonitoringResult
    • getDriftsCount

      @Nullable public Integer getDriftsCount()
      Gets the driftsCount property value. Number of drifts observed during a monitor run. Supports $filter (eq, ne, ge, le) and $orderby.
      Returns:
      a Integer
    • getErrorDetails

      @Nullable public List<ErrorDetail> getErrorDetails()
      Gets the errorDetails property value. All the error details that prevent the monitor from running successfully. The error details are a contained entity. Returned only on $select.
      Returns:
      a List<ErrorDetail>
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class Entity
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getMonitorId

      @Nullable public String getMonitorId()
      Gets the monitorId property value. Globally unique identifier (GUID) of the monitor. System-generated. Supports $filter (eq, ne).
      Returns:
      a String
    • getRunCompletionDateTime

      @Nullable public OffsetDateTime getRunCompletionDateTime()
      Gets the runCompletionDateTime property value. Date and time at which the monitor run completed. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Returns:
      a OffsetDateTime
    • getRunInitiationDateTime

      @Nullable public OffsetDateTime getRunInitiationDateTime()
      Gets the runInitiationDateTime property value. Date and time at which the monitor run initiated. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Returns:
      a OffsetDateTime
    • getRunStatus

      @Nullable public MonitorRunStatus getRunStatus()
      Gets the runStatus property value. The runStatus property
      Returns:
      a MonitorRunStatus
    • getTenantId

      @Nullable public String getTenantId()
      Gets the tenantId property value. Globally unique identifier (GUID) of the tenant for which the monitor runs. Fetched automatically by the system. Supports $filter (eq, ne).
      Returns:
      a String
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class Entity
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setDriftsCount

      public void setDriftsCount(@Nullable Integer value)
      Sets the driftsCount property value. Number of drifts observed during a monitor run. Supports $filter (eq, ne, ge, le) and $orderby.
      Parameters:
      value - Value to set for the driftsCount property.
    • setErrorDetails

      public void setErrorDetails(@Nullable List<ErrorDetail> value)
      Sets the errorDetails property value. All the error details that prevent the monitor from running successfully. The error details are a contained entity. Returned only on $select.
      Parameters:
      value - Value to set for the errorDetails property.
    • setMonitorId

      public void setMonitorId(@Nullable String value)
      Sets the monitorId property value. Globally unique identifier (GUID) of the monitor. System-generated. Supports $filter (eq, ne).
      Parameters:
      value - Value to set for the monitorId property.
    • setRunCompletionDateTime

      public void setRunCompletionDateTime(@Nullable OffsetDateTime value)
      Sets the runCompletionDateTime property value. Date and time at which the monitor run completed. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Parameters:
      value - Value to set for the runCompletionDateTime property.
    • setRunInitiationDateTime

      public void setRunInitiationDateTime(@Nullable OffsetDateTime value)
      Sets the runInitiationDateTime property value. Date and time at which the monitor run initiated. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.
      Parameters:
      value - Value to set for the runInitiationDateTime property.
    • setRunStatus

      public void setRunStatus(@Nullable MonitorRunStatus value)
      Sets the runStatus property value. The runStatus property
      Parameters:
      value - Value to set for the runStatus property.
    • setTenantId

      public void setTenantId(@Nullable String value)
      Sets the tenantId property value. Globally unique identifier (GUID) of the tenant for which the monitor runs. Fetched automatically by the system. Supports $filter (eq, ne).
      Parameters:
      value - Value to set for the tenantId property.