Package com.microsoft.graph.models
Class EmailAuthenticationMethod
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethod
com.microsoft.graph.models.EmailAuthenticationMethod
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class EmailAuthenticationMethod
extends AuthenticationMethod
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic EmailAuthenticationMethodcreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the emailAddress property value.The deserialization information for the current modelvoidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetEmailAddress(String value) Sets the emailAddress property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethod
getCreatedDateTime, setCreatedDateTimeMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
EmailAuthenticationMethod
public EmailAuthenticationMethod()Instantiates a newEmailAuthenticationMethodand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static EmailAuthenticationMethod createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
EmailAuthenticationMethod
-
getEmailAddress
Gets the emailAddress property value. The email address registered to this user.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethod- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethod- Parameters:
writer- Serialization writer to use to serialize this model
-
setEmailAddress
Sets the emailAddress property value. The email address registered to this user.- Parameters:
value- Value to set for the emailAddress property.
-