Class ExchangeMessageTrace

java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ExchangeMessageTrace
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class ExchangeMessageTrace extends Entity implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • ExchangeMessageTrace

      public ExchangeMessageTrace()
      Instantiates a new ExchangeMessageTrace and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static ExchangeMessageTrace createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a ExchangeMessageTrace
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class Entity
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getFromIP

      @Nullable public String getFromIP()
      Gets the fromIP property value. The source IP address. For incoming messages, this value is the public IP address of the SMTP email server that sent the message. Supports $filter (eq).
      Returns:
      a String
    • getMessageId

      @Nullable public String getMessageId()
      Gets the messageId property value. The Message-ID header field of the message. The format of the Message-ID depends on the messaging server that sent the message. Supports $filter (eq).
      Returns:
      a String
    • getReceivedDateTime

      @Nullable public OffsetDateTime getReceivedDateTime()
      Gets the receivedDateTime property value. The date and time when the message was received by Exchange Online. The timestamp is in UTC format. Supports $filter (ge, le).
      Returns:
      a OffsetDateTime
    • getRecipientAddress

      @Nullable public String getRecipientAddress()
      Gets the recipientAddress property value. The SMTP email address of the user that the message was addressed to. Supports $filter (eq).
      Returns:
      a String
    • getSenderAddress

      @Nullable public String getSenderAddress()
      Gets the senderAddress property value. The SMTP email address of the user the message was purportedly from. Supports $filter (eq).
      Returns:
      a String
    • getSize

      @Nullable public Integer getSize()
      Gets the size property value. The size of the message in bytes.
      Returns:
      a Integer
    • getStatus

      @Nullable public ExchangeMessageTraceStatus getStatus()
      Gets the status property value. The status property
      Returns:
      a ExchangeMessageTraceStatus
    • getSubject

      @Nullable public String getSubject()
      Gets the subject property value. The subject line of the message. Supports $filter (contains, startsWith, endsWith).
      Returns:
      a String
    • getToIP

      @Nullable public String getToIP()
      Gets the toIP property value. The destination IP address. For outgoing messages, this value is the public IP address in the resolved MX record for the destination domain. For incoming messages to Exchange Online, this value is blank. Supports $filter (eq).
      Returns:
      a String
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class Entity
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setFromIP

      public void setFromIP(@Nullable String value)
      Sets the fromIP property value. The source IP address. For incoming messages, this value is the public IP address of the SMTP email server that sent the message. Supports $filter (eq).
      Parameters:
      value - Value to set for the fromIP property.
    • setMessageId

      public void setMessageId(@Nullable String value)
      Sets the messageId property value. The Message-ID header field of the message. The format of the Message-ID depends on the messaging server that sent the message. Supports $filter (eq).
      Parameters:
      value - Value to set for the messageId property.
    • setReceivedDateTime

      public void setReceivedDateTime(@Nullable OffsetDateTime value)
      Sets the receivedDateTime property value. The date and time when the message was received by Exchange Online. The timestamp is in UTC format. Supports $filter (ge, le).
      Parameters:
      value - Value to set for the receivedDateTime property.
    • setRecipientAddress

      public void setRecipientAddress(@Nullable String value)
      Sets the recipientAddress property value. The SMTP email address of the user that the message was addressed to. Supports $filter (eq).
      Parameters:
      value - Value to set for the recipientAddress property.
    • setSenderAddress

      public void setSenderAddress(@Nullable String value)
      Sets the senderAddress property value. The SMTP email address of the user the message was purportedly from. Supports $filter (eq).
      Parameters:
      value - Value to set for the senderAddress property.
    • setSize

      public void setSize(@Nullable Integer value)
      Sets the size property value. The size of the message in bytes.
      Parameters:
      value - Value to set for the size property.
    • setStatus

      public void setStatus(@Nullable ExchangeMessageTraceStatus value)
      Sets the status property value. The status property
      Parameters:
      value - Value to set for the status property.
    • setSubject

      public void setSubject(@Nullable String value)
      Sets the subject property value. The subject line of the message. Supports $filter (contains, startsWith, endsWith).
      Parameters:
      value - Value to set for the subject property.
    • setToIP

      public void setToIP(@Nullable String value)
      Sets the toIP property value. The destination IP address. For outgoing messages, this value is the public IP address in the resolved MX record for the destination domain. For incoming messages to Exchange Online, this value is blank. Supports $filter (eq).
      Parameters:
      value - Value to set for the toIP property.