Package com.microsoft.graph.models
Class ExternalAuthenticationMethod
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethod
com.microsoft.graph.models.ExternalAuthenticationMethod
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ExternalAuthenticationMethod
extends AuthenticationMethod
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newExternalAuthenticationMethodand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptionstatic ExternalAuthenticationMethodcreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the configurationId property value.Gets the displayName property value.The deserialization information for the current modelvoidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetConfigurationId(String value) Sets the configurationId property value.voidsetDisplayName(String value) Sets the displayName property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethod
getCreatedDateTime, setCreatedDateTimeMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
ExternalAuthenticationMethod
public ExternalAuthenticationMethod()Instantiates a newExternalAuthenticationMethodand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ExternalAuthenticationMethod createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ExternalAuthenticationMethod
-
getConfigurationId
Gets the configurationId property value. A unique identifier used to manage the external auth method within Microsoft Entra ID.- Returns:
- a
String
-
getDisplayName
Gets the displayName property value. Custom name given to the registered external authentication method.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethod- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethod- Parameters:
writer- Serialization writer to use to serialize this model
-
setConfigurationId
Sets the configurationId property value. A unique identifier used to manage the external auth method within Microsoft Entra ID.- Parameters:
value- Value to set for the configurationId property.
-
setDisplayName
Sets the displayName property value. Custom name given to the registered external authentication method.- Parameters:
value- Value to set for the displayName property.
-