Class ExternalAuthenticationMethodConfiguration

All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class ExternalAuthenticationMethodConfiguration extends AuthenticationMethodConfiguration implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static ExternalAuthenticationMethodConfiguration createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a ExternalAuthenticationMethodConfiguration
    • getAppId

      @Nullable public String getAppId()
      Gets the appId property value. appId for the app registration in Microsoft Entra ID representing the integration with the external provider.
      Returns:
      a String
    • getDisplayName

      @Nullable public String getDisplayName()
      Gets the displayName property value. Display name for the external MFA. This name is shown to users during sign-in.
      Returns:
      a String
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class AuthenticationMethodConfiguration
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getIncludeTargets

      @Nullable public List<AuthenticationMethodTarget> getIncludeTargets()
      Gets the includeTargets property value. A collection of groups that are enabled to use an authentication method as part of an authentication method policy in Microsoft Entra ID.
      Returns:
      a List<AuthenticationMethodTarget>
    • getOpenIdConnectSetting

      @Nullable public OpenIdConnectSetting getOpenIdConnectSetting()
      Gets the openIdConnectSetting property value. The openIdConnectSetting property
      Returns:
      a OpenIdConnectSetting
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class AuthenticationMethodConfiguration
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setAppId

      public void setAppId(@Nullable String value)
      Sets the appId property value. appId for the app registration in Microsoft Entra ID representing the integration with the external provider.
      Parameters:
      value - Value to set for the appId property.
    • setDisplayName

      public void setDisplayName(@Nullable String value)
      Sets the displayName property value. Display name for the external MFA. This name is shown to users during sign-in.
      Parameters:
      value - Value to set for the displayName property.
    • setIncludeTargets

      public void setIncludeTargets(@Nullable List<AuthenticationMethodTarget> value)
      Sets the includeTargets property value. A collection of groups that are enabled to use an authentication method as part of an authentication method policy in Microsoft Entra ID.
      Parameters:
      value - Value to set for the includeTargets property.
    • setOpenIdConnectSetting

      public void setOpenIdConnectSetting(@Nullable OpenIdConnectSetting value)
      Sets the openIdConnectSetting property value. The openIdConnectSetting property
      Parameters:
      value - Value to set for the openIdConnectSetting property.