Class Fido2AuthenticationMethodConfiguration

All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class Fido2AuthenticationMethodConfiguration extends AuthenticationMethodConfiguration implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static Fido2AuthenticationMethodConfiguration createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a Fido2AuthenticationMethodConfiguration
    • getDefaultPasskeyProfile

      @Nullable public String getDefaultPasskeyProfile()
      Gets the defaultPasskeyProfile property value. The non-deletable baseline passkey profile, within the passkey profile collection. It's automatically created when migrating to passkey profiles and initially mirrors the tenant's legacy global passkey (FIDO2) authentication methods policy settings.
      Returns:
      a String
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class AuthenticationMethodConfiguration
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getIncludeTargets

      @Nullable public List<PasskeyAuthenticationMethodTarget> getIncludeTargets()
      Gets the includeTargets property value. A collection of groups that are enabled to use the authentication method.
      Returns:
      a List<PasskeyAuthenticationMethodTarget>
    • getIsAttestationEnforced

      @Nullable public Boolean getIsAttestationEnforced()
      Gets the isAttestationEnforced property value. Determines whether attestation must be enforced for passkey (FIDO2) registration. This property is deprecated and will be removed in October 2027. Use passkeyProfiles property.
      Returns:
      a Boolean
    • getIsSelfServiceRegistrationAllowed

      @Nullable public Boolean getIsSelfServiceRegistrationAllowed()
      Gets the isSelfServiceRegistrationAllowed property value. Determines if users can register new passkeys (FIDO2).
      Returns:
      a Boolean
    • getKeyRestrictions

      @Nullable public Fido2KeyRestrictions getKeyRestrictions()
      Gets the keyRestrictions property value. Controls whether key restrictions are enforced on passkeys (FIDO2), either allowing or disallowing certain key types as defined by Authenticator Attestation GUID (AAGUID), an identifier that indicates the type (for example, make and model) of the authenticator. This property is deprecated and will be removed in October 2027. Use the passkeyProfiles property.
      Returns:
      a Fido2KeyRestrictions
    • getPasskeyProfiles

      @Nullable public List<PasskeyProfile> getPasskeyProfiles()
      Gets the passkeyProfiles property value. A collection of configuration profiles that control the registration of and authentication with passkeys (FIDO2).
      Returns:
      a List<PasskeyProfile>
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class AuthenticationMethodConfiguration
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setDefaultPasskeyProfile

      public void setDefaultPasskeyProfile(@Nullable String value)
      Sets the defaultPasskeyProfile property value. The non-deletable baseline passkey profile, within the passkey profile collection. It's automatically created when migrating to passkey profiles and initially mirrors the tenant's legacy global passkey (FIDO2) authentication methods policy settings.
      Parameters:
      value - Value to set for the defaultPasskeyProfile property.
    • setIncludeTargets

      public void setIncludeTargets(@Nullable List<PasskeyAuthenticationMethodTarget> value)
      Sets the includeTargets property value. A collection of groups that are enabled to use the authentication method.
      Parameters:
      value - Value to set for the includeTargets property.
    • setIsAttestationEnforced

      public void setIsAttestationEnforced(@Nullable Boolean value)
      Sets the isAttestationEnforced property value. Determines whether attestation must be enforced for passkey (FIDO2) registration. This property is deprecated and will be removed in October 2027. Use passkeyProfiles property.
      Parameters:
      value - Value to set for the isAttestationEnforced property.
    • setIsSelfServiceRegistrationAllowed

      public void setIsSelfServiceRegistrationAllowed(@Nullable Boolean value)
      Sets the isSelfServiceRegistrationAllowed property value. Determines if users can register new passkeys (FIDO2).
      Parameters:
      value - Value to set for the isSelfServiceRegistrationAllowed property.
    • setKeyRestrictions

      public void setKeyRestrictions(@Nullable Fido2KeyRestrictions value)
      Sets the keyRestrictions property value. Controls whether key restrictions are enforced on passkeys (FIDO2), either allowing or disallowing certain key types as defined by Authenticator Attestation GUID (AAGUID), an identifier that indicates the type (for example, make and model) of the authenticator. This property is deprecated and will be removed in October 2027. Use the passkeyProfiles property.
      Parameters:
      value - Value to set for the keyRestrictions property.
    • setPasskeyProfiles

      public void setPasskeyProfiles(@Nullable List<PasskeyProfile> value)
      Sets the passkeyProfiles property value. A collection of configuration profiles that control the registration of and authentication with passkeys (FIDO2).
      Parameters:
      value - Value to set for the passkeyProfiles property.