Class FileStorage

java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.FileStorage
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class FileStorage extends Entity implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • FileStorage

      public FileStorage()
      Instantiates a new FileStorage and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static FileStorage createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a FileStorage
    • getContainers

      @Nullable public List<FileStorageContainer> getContainers()
      Gets the containers property value. The collection of active fileStorageContainer resources.
      Returns:
      a List<FileStorageContainer>
    • getContainerTypeRegistrations

      @Nullable public List<FileStorageContainerTypeRegistration> getContainerTypeRegistrations()
      Gets the containerTypeRegistrations property value. The collection of fileStorageContainerTypeRegistration resources.
      Returns:
      a List<FileStorageContainerTypeRegistration>
    • getContainerTypes

      @Nullable public List<FileStorageContainerType> getContainerTypes()
      Gets the containerTypes property value. The collection of fileStorageContainerType resources.
      Returns:
      a List<FileStorageContainerType>
    • getDeletedContainers

      @Nullable public List<FileStorageContainer> getDeletedContainers()
      Gets the deletedContainers property value. The collection of deleted fileStorageContainer resources.
      Returns:
      a List<FileStorageContainer>
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class Entity
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class Entity
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setContainers

      public void setContainers(@Nullable List<FileStorageContainer> value)
      Sets the containers property value. The collection of active fileStorageContainer resources.
      Parameters:
      value - Value to set for the containers property.
    • setContainerTypeRegistrations

      public void setContainerTypeRegistrations(@Nullable List<FileStorageContainerTypeRegistration> value)
      Sets the containerTypeRegistrations property value. The collection of fileStorageContainerTypeRegistration resources.
      Parameters:
      value - Value to set for the containerTypeRegistrations property.
    • setContainerTypes

      public void setContainerTypes(@Nullable List<FileStorageContainerType> value)
      Sets the containerTypes property value. The collection of fileStorageContainerType resources.
      Parameters:
      value - Value to set for the containerTypes property.
    • setDeletedContainers

      public void setDeletedContainers(@Nullable List<FileStorageContainer> value)
      Sets the deletedContainers property value. The collection of deleted fileStorageContainer resources.
      Parameters:
      value - Value to set for the deletedContainers property.