Package com.microsoft.graph.models
Class LicenseAssignmentState
java.lang.Object
com.microsoft.graph.models.LicenseAssignmentState
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class LicenseAssignmentState
extends Object
implements com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.store.BackedModel, com.microsoft.kiota.serialization.Parsable
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected com.microsoft.kiota.store.BackingStoreStores model information. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic LicenseAssignmentStatecreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the AdditionalData property value.Gets the assignedByGroup property value.com.microsoft.kiota.store.BackingStoreGets the backingStore property value.Gets the disabledPlans property value.getError()Gets the error property value.The deserialization information for the current modelGets the lastUpdatedDateTime property value.Gets the @odata.type property value.getSkuId()Gets the skuId property value.getState()Gets the state property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetAdditionalData(Map<String, Object> value) Sets the AdditionalData property value.voidsetAssignedByGroup(String value) Sets the assignedByGroup property value.voidsetBackingStore(com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value.voidsetDisabledPlans(List<UUID> value) Sets the disabledPlans property value.voidSets the error property value.voidSets the lastUpdatedDateTime property value.voidsetOdataType(String value) Sets the @odata.type property value.voidSets the skuId property value.voidSets the state property value.
-
Field Details
-
backingStore
@Nonnull protected com.microsoft.kiota.store.BackingStore backingStoreStores model information.
-
-
Constructor Details
-
LicenseAssignmentState
public LicenseAssignmentState()Instantiates a newLicenseAssignmentStateand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static LicenseAssignmentState createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
LicenseAssignmentState
-
getAdditionalData
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. -
getAssignedByGroup
Gets the assignedByGroup property value. Indicates whether the license is directly-assigned or inherited from a group. If directly-assigned, this field is null; if inherited through a group membership, this field contains the ID of the group. Read-Only.- Returns:
- a
String
-
getBackingStore
@Nonnull public com.microsoft.kiota.store.BackingStore getBackingStore()Gets the backingStore property value. Stores model information.- Specified by:
getBackingStorein interfacecom.microsoft.kiota.store.BackedModel- Returns:
- a
BackingStore
-
getDisabledPlans
Gets the disabledPlans property value. The service plans that are disabled in this assignment. Read-Only. -
getError
Gets the error property value. License assignment failure error. If the license is assigned successfully, this field will be Null. Read-Only. The possible values are CountViolation, MutuallyExclusiveViolation, DependencyViolation, ProhibitedInUsageLocationViolation, UniquenessViolation, and Other. For more information on how to identify and resolve license assignment errors, see here.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model -
getLastUpdatedDateTime
Gets the lastUpdatedDateTime property value. The timestamp when the state of the license assignment was last updated.- Returns:
- a
OffsetDateTime
-
getOdataType
Gets the @odata.type property value. The OdataType property- Returns:
- a
String
-
getSkuId
Gets the skuId property value. The unique identifier for the SKU. Read-Only.- Returns:
- a
UUID
-
getState
Gets the state property value. Indicate the current state of this assignment. Read-Only. The possible values are Active, ActiveWithError, Disabled, and Error.- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Parameters:
writer- Serialization writer to use to serialize this model
-
setAdditionalData
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.- Parameters:
value- Value to set for the AdditionalData property.
-
setAssignedByGroup
Sets the assignedByGroup property value. Indicates whether the license is directly-assigned or inherited from a group. If directly-assigned, this field is null; if inherited through a group membership, this field contains the ID of the group. Read-Only.- Parameters:
value- Value to set for the assignedByGroup property.
-
setBackingStore
public void setBackingStore(@Nonnull com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value. Stores model information.- Parameters:
value- Value to set for the backingStore property.
-
setDisabledPlans
Sets the disabledPlans property value. The service plans that are disabled in this assignment. Read-Only.- Parameters:
value- Value to set for the disabledPlans property.
-
setError
Sets the error property value. License assignment failure error. If the license is assigned successfully, this field will be Null. Read-Only. The possible values are CountViolation, MutuallyExclusiveViolation, DependencyViolation, ProhibitedInUsageLocationViolation, UniquenessViolation, and Other. For more information on how to identify and resolve license assignment errors, see here.- Parameters:
value- Value to set for the error property.
-
setLastUpdatedDateTime
Sets the lastUpdatedDateTime property value. The timestamp when the state of the license assignment was last updated.- Parameters:
value- Value to set for the lastUpdatedDateTime property.
-
setOdataType
Sets the @odata.type property value. The OdataType property- Parameters:
value- Value to set for the @odata.type property.
-
setSkuId
Sets the skuId property value. The unique identifier for the SKU. Read-Only.- Parameters:
value- Value to set for the skuId property.
-
setState
Sets the state property value. Indicate the current state of this assignment. Read-Only. The possible values are Active, ActiveWithError, Disabled, and Error.- Parameters:
value- Value to set for the state property.
-