Class MicrosoftAuthenticatorAuthenticationMethod

java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethod
com.microsoft.graph.models.MicrosoftAuthenticatorAuthenticationMethod
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class MicrosoftAuthenticatorAuthenticationMethod extends AuthenticationMethod implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static MicrosoftAuthenticatorAuthenticationMethod createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a MicrosoftAuthenticatorAuthenticationMethod
    • getDevice

      @Nullable public Device getDevice()
      Gets the device property value. The registered device on which Microsoft Authenticator resides. This property is null if the device isn't registered for passwordless Phone Sign-In.
      Returns:
      a Device
    • getDeviceTag

      @Nullable public String getDeviceTag()
      Gets the deviceTag property value. Tags containing app metadata.
      Returns:
      a String
    • getDisplayName

      @Nullable public String getDisplayName()
      Gets the displayName property value. The name of the device on which this app is registered.
      Returns:
      a String
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class AuthenticationMethod
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getPhoneAppVersion

      @Nullable public String getPhoneAppVersion()
      Gets the phoneAppVersion property value. Numerical version of this instance of the Authenticator app.
      Returns:
      a String
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class AuthenticationMethod
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setDevice

      public void setDevice(@Nullable Device value)
      Sets the device property value. The registered device on which Microsoft Authenticator resides. This property is null if the device isn't registered for passwordless Phone Sign-In.
      Parameters:
      value - Value to set for the device property.
    • setDeviceTag

      public void setDeviceTag(@Nullable String value)
      Sets the deviceTag property value. Tags containing app metadata.
      Parameters:
      value - Value to set for the deviceTag property.
    • setDisplayName

      public void setDisplayName(@Nullable String value)
      Sets the displayName property value. The name of the device on which this app is registered.
      Parameters:
      value - Value to set for the displayName property.
    • setPhoneAppVersion

      public void setPhoneAppVersion(@Nullable String value)
      Sets the phoneAppVersion property value. Numerical version of this instance of the Authenticator app.
      Parameters:
      value - Value to set for the phoneAppVersion property.