Enum Class MonitorMode

java.lang.Object
java.lang.Enum<MonitorMode>
com.microsoft.graph.models.MonitorMode
All Implemented Interfaces:
com.microsoft.kiota.serialization.ValuedEnum, Serializable, Comparable<MonitorMode>, Constable

@Generated("com.microsoft.kiota") public enum MonitorMode extends Enum<MonitorMode> implements com.microsoft.kiota.serialization.ValuedEnum
  • Enum Constant Details

    • MonitorOnly

      public static final MonitorMode MonitorOnly
    • UnknownFutureValue

      public static final MonitorMode UnknownFutureValue
      A marker value for members added after the release of this API.
  • Field Details

    • value

      public final String value
  • Method Details

    • values

      public static MonitorMode[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static MonitorMode valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getValue

      @Nonnull public String getValue()
      Specified by:
      getValue in interface com.microsoft.kiota.serialization.ValuedEnum
    • forValue

      @Nullable public static MonitorMode forValue(@Nonnull String searchValue)