Enum Class MonitorStatus

java.lang.Object
java.lang.Enum<MonitorStatus>
com.microsoft.graph.models.MonitorStatus
All Implemented Interfaces:
com.microsoft.kiota.serialization.ValuedEnum, Serializable, Comparable<MonitorStatus>, Constable

@Generated("com.microsoft.kiota") public enum MonitorStatus extends Enum<MonitorStatus> implements com.microsoft.kiota.serialization.ValuedEnum
  • Enum Constant Details

    • Active

      public static final MonitorStatus Active
    • Inactive

      public static final MonitorStatus Inactive
    • UnknownFutureValue

      public static final MonitorStatus UnknownFutureValue
      A marker value for members added after the release of this API.
  • Field Details

    • value

      public final String value
  • Method Details

    • values

      public static MonitorStatus[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static MonitorStatus valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getValue

      @Nonnull public String getValue()
      Specified by:
      getValue in interface com.microsoft.kiota.serialization.ValuedEnum
    • forValue

      @Nullable public static MonitorStatus forValue(@Nonnull String searchValue)