Class OpenIdConnectSetting

java.lang.Object
com.microsoft.graph.models.OpenIdConnectSetting
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class OpenIdConnectSetting extends Object implements com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.store.BackedModel, com.microsoft.kiota.serialization.Parsable
  • Field Details

    • backingStore

      @Nonnull protected com.microsoft.kiota.store.BackingStore backingStore
      Stores model information.
  • Constructor Details

    • OpenIdConnectSetting

      public OpenIdConnectSetting()
      Instantiates a new OpenIdConnectSetting and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static OpenIdConnectSetting createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a OpenIdConnectSetting
    • getAdditionalData

      @Nonnull public Map<String,Object> getAdditionalData()
      Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
      Specified by:
      getAdditionalData in interface com.microsoft.kiota.serialization.AdditionalDataHolder
      Returns:
      a Map<String,Object>
    • getBackingStore

      @Nonnull public com.microsoft.kiota.store.BackingStore getBackingStore()
      Gets the backingStore property value. Stores model information.
      Specified by:
      getBackingStore in interface com.microsoft.kiota.store.BackedModel
      Returns:
      a BackingStore
    • getClientId

      @Nullable public String getClientId()
      Gets the clientId property value. The Microsoft Entra ID's client ID as generated by the provider or admin to identify Microsoft Entra ID. In OIDC parlance, this is the client_id that external identity provider assigns to Microsoft Entra ID, which is also a recipient of a token from the external identity provider.
      Returns:
      a String
    • getDiscoveryUrl

      @Nullable public String getDiscoveryUrl()
      Gets the discoveryUrl property value. The host URL of the external identity provider's OIDC discovery endpoint. This endpoint must support the OIDC discovery process.
      Returns:
      a String
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getOdataType

      @Nullable public String getOdataType()
      Gets the @odata.type property value. The OdataType property
      Returns:
      a String
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setAdditionalData

      public void setAdditionalData(@Nullable Map<String,Object> value)
      Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
      Parameters:
      value - Value to set for the AdditionalData property.
    • setBackingStore

      public void setBackingStore(@Nonnull com.microsoft.kiota.store.BackingStore value)
      Sets the backingStore property value. Stores model information.
      Parameters:
      value - Value to set for the backingStore property.
    • setClientId

      public void setClientId(@Nullable String value)
      Sets the clientId property value. The Microsoft Entra ID's client ID as generated by the provider or admin to identify Microsoft Entra ID. In OIDC parlance, this is the client_id that external identity provider assigns to Microsoft Entra ID, which is also a recipient of a token from the external identity provider.
      Parameters:
      value - Value to set for the clientId property.
    • setDiscoveryUrl

      public void setDiscoveryUrl(@Nullable String value)
      Sets the discoveryUrl property value. The host URL of the external identity provider's OIDC discovery endpoint. This endpoint must support the OIDC discovery process.
      Parameters:
      value - Value to set for the discoveryUrl property.
    • setOdataType

      public void setOdataType(@Nullable String value)
      Sets the @odata.type property value. The OdataType property
      Parameters:
      value - Value to set for the @odata.type property.