Class PasskeyAuthenticationMethodTarget

All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class PasskeyAuthenticationMethodTarget extends AuthenticationMethodTarget implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static PasskeyAuthenticationMethodTarget createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a PasskeyAuthenticationMethodTarget
    • getAllowedPasskeyProfiles

      @Nullable public List<UUID> getAllowedPasskeyProfiles()
      Gets the allowedPasskeyProfiles property value. List of passkey profiles scoped to the targets. Required.
      Returns:
      a List<UUID>
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class AuthenticationMethodTarget
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class AuthenticationMethodTarget
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setAllowedPasskeyProfiles

      public void setAllowedPasskeyProfiles(@Nullable List<UUID> value)
      Sets the allowedPasskeyProfiles property value. List of passkey profiles scoped to the targets. Required.
      Parameters:
      value - Value to set for the allowedPasskeyProfiles property.