Class ProcessConversationMetadata

java.lang.Object
com.microsoft.graph.models.ProcessContentMetadataBase
com.microsoft.graph.models.ProcessConversationMetadata
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class ProcessConversationMetadata extends ProcessContentMetadataBase implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • ProcessConversationMetadata

      public ProcessConversationMetadata()
      Instantiates a new ProcessConversationMetadata and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static ProcessConversationMetadata createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a ProcessConversationMetadata
    • getAccessedResources

      @Nullable public List<String> getAccessedResources()
      Gets the accessedResources property value. List of resources (for example, file URLs, web URLs) accessed during the generation of this message (relevant for bot interactions). The accessedResources property is deprecated and stopped returning data on August 20, 2025. Going forward, use the accessedResources_v2 property.
      Returns:
      a List<String>
    • getAccessedResourcesV2

      @Nullable public List<ResourceAccessDetail> getAccessedResourcesV2()
      Gets the accessedResources_v2 property value. Lists details about the resources accessed by AI agents, such as identifiers, access type, and status.
      Returns:
      a List<ResourceAccessDetail>
    • getAgents

      @Nullable public List<AiAgentInfo> getAgents()
      Gets the agents property value. Indicates the information about an AI agent that participated in the preparation of the message.
      Returns:
      a List<AiAgentInfo>
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class ProcessContentMetadataBase
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getParentMessageId

      @Nullable public String getParentMessageId()
      Gets the parentMessageId property value. Identifier of the parent message in a threaded conversation, if applicable.
      Returns:
      a String
    • getPlugins

      @Nullable public List<AiInteractionPlugin> getPlugins()
      Gets the plugins property value. List of plugins used during the generation of this message (relevant for AI/bot interactions).
      Returns:
      a List<AiInteractionPlugin>
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class ProcessContentMetadataBase
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setAccessedResources

      public void setAccessedResources(@Nullable List<String> value)
      Sets the accessedResources property value. List of resources (for example, file URLs, web URLs) accessed during the generation of this message (relevant for bot interactions). The accessedResources property is deprecated and stopped returning data on August 20, 2025. Going forward, use the accessedResources_v2 property.
      Parameters:
      value - Value to set for the accessedResources property.
    • setAccessedResourcesV2

      public void setAccessedResourcesV2(@Nullable List<ResourceAccessDetail> value)
      Sets the accessedResources_v2 property value. Lists details about the resources accessed by AI agents, such as identifiers, access type, and status.
      Parameters:
      value - Value to set for the accessedResources_v2 property.
    • setAgents

      public void setAgents(@Nullable List<AiAgentInfo> value)
      Sets the agents property value. Indicates the information about an AI agent that participated in the preparation of the message.
      Parameters:
      value - Value to set for the agents property.
    • setParentMessageId

      public void setParentMessageId(@Nullable String value)
      Sets the parentMessageId property value. Identifier of the parent message in a threaded conversation, if applicable.
      Parameters:
      value - Value to set for the parentMessageId property.
    • setPlugins

      public void setPlugins(@Nullable List<AiInteractionPlugin> value)
      Sets the plugins property value. List of plugins used during the generation of this message (relevant for AI/bot interactions).
      Parameters:
      value - Value to set for the plugins property.