Class ProfileSource

java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ProfileSource
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class ProfileSource extends Entity implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • ProfileSource

      public ProfileSource()
      Instantiates a new ProfileSource and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static ProfileSource createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a ProfileSource
    • getDisplayName

      @Nullable public String getDisplayName()
      Gets the displayName property value. Name of the profile source intended to inform users about the profile source name.
      Returns:
      a String
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class Entity
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getKind

      @Nullable public String getKind()
      Gets the kind property value. Type of the profile source.
      Returns:
      a String
    • getLocalizations

      @Nullable public List<ProfileSourceLocalization> getLocalizations()
      Gets the localizations property value. Alternative localized labels specified by an administrator.
      Returns:
      a List<ProfileSourceLocalization>
    • getSourceId

      @Nullable public String getSourceId()
      Gets the sourceId property value. Profile source identifier used as an alternate key.
      Returns:
      a String
    • getWebUrl

      @Nullable public String getWebUrl()
      Gets the webUrl property value. Web URL of the profile source that directs users to the page view of the profile data.
      Returns:
      a String
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class Entity
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setDisplayName

      public void setDisplayName(@Nullable String value)
      Sets the displayName property value. Name of the profile source intended to inform users about the profile source name.
      Parameters:
      value - Value to set for the displayName property.
    • setKind

      public void setKind(@Nullable String value)
      Sets the kind property value. Type of the profile source.
      Parameters:
      value - Value to set for the kind property.
    • setLocalizations

      public void setLocalizations(@Nullable List<ProfileSourceLocalization> value)
      Sets the localizations property value. Alternative localized labels specified by an administrator.
      Parameters:
      value - Value to set for the localizations property.
    • setSourceId

      public void setSourceId(@Nullable String value)
      Sets the sourceId property value. Profile source identifier used as an alternate key.
      Parameters:
      value - Value to set for the sourceId property.
    • setWebUrl

      public void setWebUrl(@Nullable String value)
      Sets the webUrl property value. Web URL of the profile source that directs users to the page view of the profile data.
      Parameters:
      value - Value to set for the webUrl property.