Package com.microsoft.graph.models
Class ProfileSourceLocalization
java.lang.Object
com.microsoft.graph.models.ProfileSourceLocalization
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ProfileSourceLocalization
extends Object
implements com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.store.BackedModel, com.microsoft.kiota.serialization.Parsable
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected com.microsoft.kiota.store.BackingStoreStores model information. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ProfileSourceLocalizationcreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the AdditionalData property value.com.microsoft.kiota.store.BackingStoreGets the backingStore property value.Gets the displayName property value.The deserialization information for the current modelGets the languageTag property value.Gets the @odata.type property value.Gets the webUrl property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetAdditionalData(Map<String, Object> value) Sets the AdditionalData property value.voidsetBackingStore(com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value.voidsetDisplayName(String value) Sets the displayName property value.voidsetLanguageTag(String value) Sets the languageTag property value.voidsetOdataType(String value) Sets the @odata.type property value.voidSets the webUrl property value.
-
Field Details
-
backingStore
@Nonnull protected com.microsoft.kiota.store.BackingStore backingStoreStores model information.
-
-
Constructor Details
-
ProfileSourceLocalization
public ProfileSourceLocalization()Instantiates a newProfileSourceLocalizationand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ProfileSourceLocalization createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ProfileSourceLocalization
-
getAdditionalData
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. -
getBackingStore
@Nonnull public com.microsoft.kiota.store.BackingStore getBackingStore()Gets the backingStore property value. Stores model information.- Specified by:
getBackingStorein interfacecom.microsoft.kiota.store.BackedModel- Returns:
- a
BackingStore
-
getDisplayName
Gets the displayName property value. Localized display name.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model -
getLanguageTag
Gets the languageTag property value. Language locale.- Returns:
- a
String
-
getOdataType
Gets the @odata.type property value. The OdataType property- Returns:
- a
String
-
getWebUrl
Gets the webUrl property value. Localized profile source URL.- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Parameters:
writer- Serialization writer to use to serialize this model
-
setAdditionalData
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.- Parameters:
value- Value to set for the AdditionalData property.
-
setBackingStore
public void setBackingStore(@Nonnull com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value. Stores model information.- Parameters:
value- Value to set for the backingStore property.
-
setDisplayName
Sets the displayName property value. Localized display name.- Parameters:
value- Value to set for the displayName property.
-
setLanguageTag
Sets the languageTag property value. Language locale.- Parameters:
value- Value to set for the languageTag property.
-
setOdataType
Sets the @odata.type property value. The OdataType property- Parameters:
value- Value to set for the @odata.type property.
-
setWebUrl
Sets the webUrl property value. Localized profile source URL.- Parameters:
value- Value to set for the webUrl property.
-