Package com.microsoft.graph.models
Class ProtectionPolicyArtifactCount
java.lang.Object
com.microsoft.graph.models.ProtectionPolicyArtifactCount
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ProtectionPolicyArtifactCount
extends Object
implements com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.store.BackedModel, com.microsoft.kiota.serialization.Parsable
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected com.microsoft.kiota.store.BackingStoreStores model information. -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newProtectionPolicyArtifactCountand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptioncreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the AdditionalData property value.com.microsoft.kiota.store.BackingStoreGets the backingStore property value.Gets the completed property value.Gets the failed property value.The deserialization information for the current modelGets the inProgress property value.Gets the @odata.type property value.getTotal()Gets the total property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetAdditionalData(Map<String, Object> value) Sets the AdditionalData property value.voidsetBackingStore(com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value.voidsetCompleted(Integer value) Sets the completed property value.voidSets the failed property value.voidsetInProgress(Integer value) Sets the inProgress property value.voidsetOdataType(String value) Sets the @odata.type property value.voidSets the total property value.
-
Field Details
-
backingStore
@Nonnull protected com.microsoft.kiota.store.BackingStore backingStoreStores model information.
-
-
Constructor Details
-
ProtectionPolicyArtifactCount
public ProtectionPolicyArtifactCount()Instantiates a newProtectionPolicyArtifactCountand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ProtectionPolicyArtifactCount createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ProtectionPolicyArtifactCount
-
getAdditionalData
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. -
getBackingStore
@Nonnull public com.microsoft.kiota.store.BackingStore getBackingStore()Gets the backingStore property value. Stores model information.- Specified by:
getBackingStorein interfacecom.microsoft.kiota.store.BackedModel- Returns:
- a
BackingStore
-
getCompleted
Gets the completed property value. The completed property- Returns:
- a
Integer
-
getFailed
Gets the failed property value. The failed property- Returns:
- a
Integer
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model -
getInProgress
Gets the inProgress property value. The inProgress property- Returns:
- a
Integer
-
getOdataType
Gets the @odata.type property value. The OdataType property- Returns:
- a
String
-
getTotal
Gets the total property value. The total property- Returns:
- a
Integer
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Parameters:
writer- Serialization writer to use to serialize this model
-
setAdditionalData
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.- Parameters:
value- Value to set for the AdditionalData property.
-
setBackingStore
public void setBackingStore(@Nonnull com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value. Stores model information.- Parameters:
value- Value to set for the backingStore property.
-
setCompleted
Sets the completed property value. The completed property- Parameters:
value- Value to set for the completed property.
-
setFailed
Sets the failed property value. The failed property- Parameters:
value- Value to set for the failed property.
-
setInProgress
Sets the inProgress property value. The inProgress property- Parameters:
value- Value to set for the inProgress property.
-
setOdataType
Sets the @odata.type property value. The OdataType property- Parameters:
value- Value to set for the @odata.type property.
-
setTotal
Sets the total property value. The total property- Parameters:
value- Value to set for the total property.
-