Class QrCodePinAuthenticationMethod

All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class QrCodePinAuthenticationMethod extends AuthenticationMethod implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • QrCodePinAuthenticationMethod

      public QrCodePinAuthenticationMethod()
      Instantiates a new QrCodePinAuthenticationMethod and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static QrCodePinAuthenticationMethod createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a QrCodePinAuthenticationMethod
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class AuthenticationMethod
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getPin

      @Nullable public QrPin getPin()
      Gets the pin property value. The PIN associated with this QR code authentication method.
      Returns:
      a QrPin
    • getStandardQRCode

      @Nullable public QrCode getStandardQRCode()
      Gets the standardQRCode property value. The standard (long-lived) QR code credential, typically printed on a user's badge.
      Returns:
      a QrCode
    • getTemporaryQRCode

      @Nullable public QrCode getTemporaryQRCode()
      Gets the temporaryQRCode property value. A temporary (short-lived) QR code credential, created when a user forgets their badge.
      Returns:
      a QrCode
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class AuthenticationMethod
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setPin

      public void setPin(@Nullable QrPin value)
      Sets the pin property value. The PIN associated with this QR code authentication method.
      Parameters:
      value - Value to set for the pin property.
    • setStandardQRCode

      public void setStandardQRCode(@Nullable QrCode value)
      Sets the standardQRCode property value. The standard (long-lived) QR code credential, typically printed on a user's badge.
      Parameters:
      value - Value to set for the standardQRCode property.
    • setTemporaryQRCode

      public void setTemporaryQRCode(@Nullable QrCode value)
      Sets the temporaryQRCode property value. A temporary (short-lived) QR code credential, created when a user forgets their badge.
      Parameters:
      value - Value to set for the temporaryQRCode property.