Class SharePointIdentitySet

java.lang.Object
com.microsoft.graph.models.IdentitySet
com.microsoft.graph.models.SharePointIdentitySet
All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.serialization.Parsable, com.microsoft.kiota.store.BackedModel

@Generated("com.microsoft.kiota") public class SharePointIdentitySet extends IdentitySet implements com.microsoft.kiota.serialization.Parsable
  • Constructor Details

    • SharePointIdentitySet

      public SharePointIdentitySet()
      Instantiates a new SharePointIdentitySet and sets the default values.
  • Method Details

    • createFromDiscriminatorValue

      @Nonnull public static SharePointIdentitySet createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode)
      Creates a new instance of the appropriate class based on discriminator value
      Parameters:
      parseNode - The parse node to use to read the discriminator value and create the object
      Returns:
      a SharePointIdentitySet
    • getFieldDeserializers

      @Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()
      The deserialization information for the current model
      Specified by:
      getFieldDeserializers in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      getFieldDeserializers in class IdentitySet
      Returns:
      a Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
    • getGroup

      @Nullable public Identity getGroup()
      Gets the group property value. The group associated with this action. Optional.
      Returns:
      a Identity
    • getSharePointGroup

      @Nullable public SharePointGroupIdentity getSharePointGroup()
      Gets the sharePointGroup property value. The SharePoint group associated with this action, identified by a globally unique ID. Use this property instead of siteGroup when available. Optional.
      Returns:
      a SharePointGroupIdentity
    • getSiteGroup

      @Nullable public SharePointIdentity getSiteGroup()
      Gets the siteGroup property value. The SharePoint group associated with this action, identified by a principal ID that is unique only within the site. Optional.
      Returns:
      a SharePointIdentity
    • getSiteUser

      @Nullable public SharePointIdentity getSiteUser()
      Gets the siteUser property value. The SharePoint user associated with this action. Optional.
      Returns:
      a SharePointIdentity
    • serialize

      public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer)
      Serializes information the current object
      Specified by:
      serialize in interface com.microsoft.kiota.serialization.Parsable
      Overrides:
      serialize in class IdentitySet
      Parameters:
      writer - Serialization writer to use to serialize this model
    • setGroup

      public void setGroup(@Nullable Identity value)
      Sets the group property value. The group associated with this action. Optional.
      Parameters:
      value - Value to set for the group property.
    • setSharePointGroup

      public void setSharePointGroup(@Nullable SharePointGroupIdentity value)
      Sets the sharePointGroup property value. The SharePoint group associated with this action, identified by a globally unique ID. Use this property instead of siteGroup when available. Optional.
      Parameters:
      value - Value to set for the sharePointGroup property.
    • setSiteGroup

      public void setSiteGroup(@Nullable SharePointIdentity value)
      Sets the siteGroup property value. The SharePoint group associated with this action, identified by a principal ID that is unique only within the site. Optional.
      Parameters:
      value - Value to set for the siteGroup property.
    • setSiteUser

      public void setSiteUser(@Nullable SharePointIdentity value)
      Sets the siteUser property value. The SharePoint user associated with this action. Optional.
      Parameters:
      value - Value to set for the siteUser property.