Package com.microsoft.graph.models
Class SoftwareOathAuthenticationMethod
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethod
com.microsoft.graph.models.SoftwareOathAuthenticationMethod
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class SoftwareOathAuthenticationMethod
extends AuthenticationMethod
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newSoftwareOathAuthenticationMethodand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptioncreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueThe deserialization information for the current modelGets the secretKey property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetSecretKey(String value) Sets the secretKey property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethod
getCreatedDateTime, setCreatedDateTimeMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
SoftwareOathAuthenticationMethod
public SoftwareOathAuthenticationMethod()Instantiates a newSoftwareOathAuthenticationMethodand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static SoftwareOathAuthenticationMethod createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
SoftwareOathAuthenticationMethod
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethod- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getSecretKey
Gets the secretKey property value. The secret key of the method. Always returns null.- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethod- Parameters:
writer- Serialization writer to use to serialize this model
-
setSecretKey
Sets the secretKey property value. The secret key of the method. Always returns null.- Parameters:
value- Value to set for the secretKey property.
-