Package com.microsoft.graph.models
Class WindowsHelloForBusinessAuthenticationMethod
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethod
com.microsoft.graph.models.WindowsHelloForBusinessAuthenticationMethod
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class WindowsHelloForBusinessAuthenticationMethod
extends AuthenticationMethod
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newWindowsHelloForBusinessAuthenticationMethodand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptioncreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the device property value.Gets the displayName property value.The deserialization information for the current modelGets the keyStrength property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidSets the device property value.voidsetDisplayName(String value) Sets the displayName property value.voidSets the keyStrength property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethod
getCreatedDateTime, setCreatedDateTimeMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
WindowsHelloForBusinessAuthenticationMethod
public WindowsHelloForBusinessAuthenticationMethod()Instantiates a newWindowsHelloForBusinessAuthenticationMethodand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static WindowsHelloForBusinessAuthenticationMethod createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
WindowsHelloForBusinessAuthenticationMethod
-
getDevice
Gets the device property value. The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/[email protected]/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.- Returns:
- a
Device
-
getDisplayName
Gets the displayName property value. The name of the device on which Windows Hello for Business is registered- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethod- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getKeyStrength
Gets the keyStrength property value. Key strength of this Windows Hello for Business key. The possible values are: normal, weak, unknown.- Returns:
- a
AuthenticationMethodKeyStrength
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethod- Parameters:
writer- Serialization writer to use to serialize this model
-
setDevice
Sets the device property value. The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/[email protected]/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.- Parameters:
value- Value to set for the device property.
-
setDisplayName
Sets the displayName property value. The name of the device on which Windows Hello for Business is registered- Parameters:
value- Value to set for the displayName property.
-
setKeyStrength
Sets the keyStrength property value. Key strength of this Windows Hello for Business key. The possible values are: normal, weak, unknown.- Parameters:
value- Value to set for the keyStrength property.
-