Class MailboxConfigurationEvidence
java.lang.Object
com.microsoft.graph.models.security.AlertEvidence
com.microsoft.graph.models.security.MailboxConfigurationEvidence
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class MailboxConfigurationEvidence
extends AlertEvidence
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.security.AlertEvidence
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newMailboxConfigurationEvidenceand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptionstatic MailboxConfigurationEvidencecreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the configurationId property value.Gets the configurationType property value.Gets the displayName property value.Gets the externalDirectoryObjectId property value.The deserialization information for the current modelGets the mailboxPrimaryAddress property value.getUpn()Gets the upn property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetConfigurationId(String value) Sets the configurationId property value.voidSets the configurationType property value.voidsetDisplayName(String value) Sets the displayName property value.voidsetExternalDirectoryObjectId(UUID value) Sets the externalDirectoryObjectId property value.voidsetMailboxPrimaryAddress(String value) Sets the mailboxPrimaryAddress property value.voidSets the upn property value.Methods inherited from class com.microsoft.graph.models.security.AlertEvidence
getAdditionalData, getBackingStore, getCreatedDateTime, getDetailedRoles, getOdataType, getRemediationStatus, getRemediationStatusDetails, getRoles, getTags, getVerdict, setAdditionalData, setBackingStore, setCreatedDateTime, setDetailedRoles, setOdataType, setRemediationStatus, setRemediationStatusDetails, setRoles, setTags, setVerdict
-
Constructor Details
-
MailboxConfigurationEvidence
public MailboxConfigurationEvidence()Instantiates a newMailboxConfigurationEvidenceand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static MailboxConfigurationEvidence createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
MailboxConfigurationEvidence
-
getConfigurationId
Gets the configurationId property value. The unique identifier of the mailbox configuration.- Returns:
- a
String
-
getConfigurationType
Gets the configurationType property value. The type of mailbox configuration. The possible values are: mailForwardingRule, owaSettings, ewsSettings, mailDelegation, userInboxRule, unknownFutureValue.- Returns:
- a
MailboxConfigurationType
-
getDisplayName
Gets the displayName property value. The display name of the mailbox.- Returns:
- a
String
-
getExternalDirectoryObjectId
Gets the externalDirectoryObjectId property value. The external directory object identifier of the mailbox.- Returns:
- a
UUID
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAlertEvidence- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getMailboxPrimaryAddress
Gets the mailboxPrimaryAddress property value. The primary email address of the mailbox.- Returns:
- a
String
-
getUpn
Gets the upn property value. The user principal name (UPN) of the mailbox.- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAlertEvidence- Parameters:
writer- Serialization writer to use to serialize this model
-
setConfigurationId
Sets the configurationId property value. The unique identifier of the mailbox configuration.- Parameters:
value- Value to set for the configurationId property.
-
setConfigurationType
Sets the configurationType property value. The type of mailbox configuration. The possible values are: mailForwardingRule, owaSettings, ewsSettings, mailDelegation, userInboxRule, unknownFutureValue.- Parameters:
value- Value to set for the configurationType property.
-
setDisplayName
Sets the displayName property value. The display name of the mailbox.- Parameters:
value- Value to set for the displayName property.
-
setExternalDirectoryObjectId
Sets the externalDirectoryObjectId property value. The external directory object identifier of the mailbox.- Parameters:
value- Value to set for the externalDirectoryObjectId property.
-
setMailboxPrimaryAddress
Sets the mailboxPrimaryAddress property value. The primary email address of the mailbox.- Parameters:
value- Value to set for the mailboxPrimaryAddress property.
-
setUpn
Sets the upn property value. The user principal name (UPN) of the mailbox.- Parameters:
value- Value to set for the upn property.
-