Package com.microsoft.graph.models
Class ConfigurationBaseline
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ConfigurationBaseline
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ConfigurationBaseline
extends Entity
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ConfigurationBaselinecreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the description property value.Gets the displayName property value.The deserialization information for the current modelGets the parameters property value.Gets the resources property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetDescription(String value) Sets the description property value.voidsetDisplayName(String value) Sets the displayName property value.voidsetParameters(List<BaselineParameter> value) Sets the parameters property value.voidsetResources(List<BaselineResource> value) Sets the resources property value.Methods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
ConfigurationBaseline
public ConfigurationBaseline()Instantiates a newConfigurationBaselineand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ConfigurationBaseline createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ConfigurationBaseline
-
getDescription
Gets the description property value. User-friendly description of the baseline given by the user.- Returns:
- a
String
-
getDisplayName
Gets the displayName property value. User-friendly name given by the user to the baseline.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classEntity- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getParameters
Gets the parameters property value. Collection of parameters attached to the baseline.- Returns:
- a
List<BaselineParameter>
-
getResources
Gets the resources property value. Collection of resources and their properties that are added to the baseline. At least one property of one resource must be present in the baseline.- Returns:
- a
List<BaselineResource>
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object -
setDescription
Sets the description property value. User-friendly description of the baseline given by the user.- Parameters:
value- Value to set for the description property.
-
setDisplayName
Sets the displayName property value. User-friendly name given by the user to the baseline.- Parameters:
value- Value to set for the displayName property.
-
setParameters
Sets the parameters property value. Collection of parameters attached to the baseline.- Parameters:
value- Value to set for the parameters property.
-
setResources
Sets the resources property value. Collection of resources and their properties that are added to the baseline. At least one property of one resource must be present in the baseline.- Parameters:
value- Value to set for the resources property.
-