Package com.microsoft.graph.models
Class ConfigurationMonitor
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ConfigurationMonitor
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ConfigurationMonitor
extends Entity
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ConfigurationMonitorcreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the baseline property value.Gets the createdBy property value.Gets the createdDateTime property value.Gets the description property value.Gets the displayName property value.The deserialization information for the current modelGets the inactivationReason property value.Gets the lastModifiedBy property value.Gets the lastModifiedDateTime property value.getMode()Gets the mode property value.Gets the monitorRunFrequencyInHours property value.Gets the parameters property value.Gets the status property value.Gets the tenantId property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetBaseline(ConfigurationBaseline value) Sets the baseline property value.voidsetCreatedBy(IdentitySet value) Sets the createdBy property value.voidsetCreatedDateTime(OffsetDateTime value) Sets the createdDateTime property value.voidsetDescription(String value) Sets the description property value.voidsetDisplayName(String value) Sets the displayName property value.voidsetInactivationReason(String value) Sets the inactivationReason property value.voidsetLastModifiedBy(IdentitySet value) Sets the lastModifiedBy property value.voidSets the lastModifiedDateTime property value.voidsetMode(MonitorMode value) Sets the mode property value.voidSets the monitorRunFrequencyInHours property value.voidSets the parameters property value.voidsetStatus(MonitorStatus value) Sets the status property value.voidsetTenantId(String value) Sets the tenantId property value.Methods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
ConfigurationMonitor
public ConfigurationMonitor()Instantiates a newConfigurationMonitorand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ConfigurationMonitor createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ConfigurationMonitor
-
getBaseline
Gets the baseline property value. The baseline property- Returns:
- a
ConfigurationBaseline
-
getCreatedBy
Gets the createdBy property value. The createdBy property- Returns:
- a
IdentitySet
-
getCreatedDateTime
Gets the createdDateTime property value. The date and time when the monitor was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.- Returns:
- a
OffsetDateTime
-
getDescription
Gets the description property value. User-friendly description of the monitor given by the user. Supports $filter (eq, ne, startsWith) and $orderby.- Returns:
- a
String
-
getDisplayName
Gets the displayName property value. User-friendly name given by the user to the monitor. Supports $filter (eq, ne, startsWith) and $orderby.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classEntity- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getInactivationReason
Gets the inactivationReason property value. The reason for the monitor's inactivation. Requires $select to retrieve.- Returns:
- a
String
-
getLastModifiedBy
Gets the lastModifiedBy property value. The lastModifiedBy property- Returns:
- a
IdentitySet
-
getLastModifiedDateTime
Gets the lastModifiedDateTime property value. The date and time when the monitor was last modified. If no modifications are made to the monitor, it's the same as createdDateTime. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.- Returns:
- a
OffsetDateTime
-
getMode
Gets the mode property value. The mode property- Returns:
- a
MonitorMode
-
getMonitorRunFrequencyInHours
Gets the monitorRunFrequencyInHours property value. Frequency at which the monitor runs. The default frequency is six hours. Regardless of when you create or update a monitor, it gets triggered within the next 6 hours. Currently, monitors are picked up at fixed times: 6 AM, 12 PM, 6 PM, and 12 AM (all in GMT). For example, if you create a monitor at 9 AM, it gets triggered around 12 PM. If you update a monitor at 4 PM, it gets triggered around 6 PM.- Returns:
- a
Integer
-
getParameters
Gets the parameters property value. Key-value pairs that contain parameter values which might be used in the baseline. Requires $select to retrieve.- Returns:
- a
OpenComplexDictionaryType
-
getStatus
Gets the status property value. The status property- Returns:
- a
MonitorStatus
-
getTenantId
Gets the tenantId property value. Globally unique identifier (GUID) of the tenant for which the monitor runs. Fetched automatically by the system. Supports $filter (eq, ne).- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object -
setBaseline
Sets the baseline property value. The baseline property- Parameters:
value- Value to set for the baseline property.
-
setCreatedBy
Sets the createdBy property value. The createdBy property- Parameters:
value- Value to set for the createdBy property.
-
setCreatedDateTime
Sets the createdDateTime property value. The date and time when the monitor was created. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.- Parameters:
value- Value to set for the createdDateTime property.
-
setDescription
Sets the description property value. User-friendly description of the monitor given by the user. Supports $filter (eq, ne, startsWith) and $orderby.- Parameters:
value- Value to set for the description property.
-
setDisplayName
Sets the displayName property value. User-friendly name given by the user to the monitor. Supports $filter (eq, ne, startsWith) and $orderby.- Parameters:
value- Value to set for the displayName property.
-
setInactivationReason
Sets the inactivationReason property value. The reason for the monitor's inactivation. Requires $select to retrieve.- Parameters:
value- Value to set for the inactivationReason property.
-
setLastModifiedBy
Sets the lastModifiedBy property value. The lastModifiedBy property- Parameters:
value- Value to set for the lastModifiedBy property.
-
setLastModifiedDateTime
Sets the lastModifiedDateTime property value. The date and time when the monitor was last modified. If no modifications are made to the monitor, it's the same as createdDateTime. The timestamp type represents date and time information using ISO 8601 format and is always in UTC. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, ge, le) and $orderby.- Parameters:
value- Value to set for the lastModifiedDateTime property.
-
setMode
Sets the mode property value. The mode property- Parameters:
value- Value to set for the mode property.
-
setMonitorRunFrequencyInHours
Sets the monitorRunFrequencyInHours property value. Frequency at which the monitor runs. The default frequency is six hours. Regardless of when you create or update a monitor, it gets triggered within the next 6 hours. Currently, monitors are picked up at fixed times: 6 AM, 12 PM, 6 PM, and 12 AM (all in GMT). For example, if you create a monitor at 9 AM, it gets triggered around 12 PM. If you update a monitor at 4 PM, it gets triggered around 6 PM.- Parameters:
value- Value to set for the monitorRunFrequencyInHours property.
-
setParameters
Sets the parameters property value. Key-value pairs that contain parameter values which might be used in the baseline. Requires $select to retrieve.- Parameters:
value- Value to set for the parameters property.
-
setStatus
Sets the status property value. The status property- Parameters:
value- Value to set for the status property.
-
setTenantId
Sets the tenantId property value. Globally unique identifier (GUID) of the tenant for which the monitor runs. Fetched automatically by the system. Supports $filter (eq, ne).- Parameters:
value- Value to set for the tenantId property.
-