Package com.microsoft.graph.models
Class ExchangeMessageTrace
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ExchangeMessageTrace
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ExchangeMessageTrace
extends Entity
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ExchangeMessageTracecreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueThe deserialization information for the current modelGets the fromIP property value.Gets the messageId property value.Gets the receivedDateTime property value.Gets the recipientAddress property value.Gets the senderAddress property value.getSize()Gets the size property value.Gets the status property value.Gets the subject property value.getToIP()Gets the toIP property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidSets the fromIP property value.voidsetMessageId(String value) Sets the messageId property value.voidSets the receivedDateTime property value.voidsetRecipientAddress(String value) Sets the recipientAddress property value.voidsetSenderAddress(String value) Sets the senderAddress property value.voidSets the size property value.voidSets the status property value.voidsetSubject(String value) Sets the subject property value.voidSets the toIP property value.Methods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
ExchangeMessageTrace
public ExchangeMessageTrace()Instantiates a newExchangeMessageTraceand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ExchangeMessageTrace createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ExchangeMessageTrace
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classEntity- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getFromIP
Gets the fromIP property value. The source IP address. For incoming messages, this value is the public IP address of the SMTP email server that sent the message. Supports $filter (eq).- Returns:
- a
String
-
getMessageId
Gets the messageId property value. The Message-ID header field of the message. The format of the Message-ID depends on the messaging server that sent the message. Supports $filter (eq).- Returns:
- a
String
-
getReceivedDateTime
Gets the receivedDateTime property value. The date and time when the message was received by Exchange Online. The timestamp is in UTC format. Supports $filter (ge, le).- Returns:
- a
OffsetDateTime
-
getRecipientAddress
Gets the recipientAddress property value. The SMTP email address of the user that the message was addressed to. Supports $filter (eq).- Returns:
- a
String
-
getSenderAddress
Gets the senderAddress property value. The SMTP email address of the user the message was purportedly from. Supports $filter (eq).- Returns:
- a
String
-
getSize
Gets the size property value. The size of the message in bytes.- Returns:
- a
Integer
-
getStatus
Gets the status property value. The status property- Returns:
- a
ExchangeMessageTraceStatus
-
getSubject
Gets the subject property value. The subject line of the message. Supports $filter (contains, startsWith, endsWith).- Returns:
- a
String
-
getToIP
Gets the toIP property value. The destination IP address. For outgoing messages, this value is the public IP address in the resolved MX record for the destination domain. For incoming messages to Exchange Online, this value is blank. Supports $filter (eq).- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object -
setFromIP
Sets the fromIP property value. The source IP address. For incoming messages, this value is the public IP address of the SMTP email server that sent the message. Supports $filter (eq).- Parameters:
value- Value to set for the fromIP property.
-
setMessageId
Sets the messageId property value. The Message-ID header field of the message. The format of the Message-ID depends on the messaging server that sent the message. Supports $filter (eq).- Parameters:
value- Value to set for the messageId property.
-
setReceivedDateTime
Sets the receivedDateTime property value. The date and time when the message was received by Exchange Online. The timestamp is in UTC format. Supports $filter (ge, le).- Parameters:
value- Value to set for the receivedDateTime property.
-
setRecipientAddress
Sets the recipientAddress property value. The SMTP email address of the user that the message was addressed to. Supports $filter (eq).- Parameters:
value- Value to set for the recipientAddress property.
-
setSenderAddress
Sets the senderAddress property value. The SMTP email address of the user the message was purportedly from. Supports $filter (eq).- Parameters:
value- Value to set for the senderAddress property.
-
setSize
Sets the size property value. The size of the message in bytes.- Parameters:
value- Value to set for the size property.
-
setStatus
Sets the status property value. The status property- Parameters:
value- Value to set for the status property.
-
setSubject
Sets the subject property value. The subject line of the message. Supports $filter (contains, startsWith, endsWith).- Parameters:
value- Value to set for the subject property.
-
setToIP
Sets the toIP property value. The destination IP address. For outgoing messages, this value is the public IP address in the resolved MX record for the destination domain. For incoming messages to Exchange Online, this value is blank. Supports $filter (eq).- Parameters:
value- Value to set for the toIP property.
-