Package com.microsoft.graph.models
Class ExternalAuthenticationMethodConfiguration
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethodConfiguration
com.microsoft.graph.models.ExternalAuthenticationMethodConfiguration
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ExternalAuthenticationMethodConfiguration
extends AuthenticationMethodConfiguration
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newExternalAuthenticationMethodConfigurationand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptioncreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valuegetAppId()Gets the appId property value.Gets the displayName property value.The deserialization information for the current modelGets the includeTargets property value.Gets the openIdConnectSetting property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidSets the appId property value.voidsetDisplayName(String value) Sets the displayName property value.voidSets the includeTargets property value.voidSets the openIdConnectSetting property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethodConfiguration
getExcludeTargets, getState, setExcludeTargets, setStateMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
ExternalAuthenticationMethodConfiguration
public ExternalAuthenticationMethodConfiguration()Instantiates a newExternalAuthenticationMethodConfigurationand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ExternalAuthenticationMethodConfiguration createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ExternalAuthenticationMethodConfiguration
-
getAppId
Gets the appId property value. appId for the app registration in Microsoft Entra ID representing the integration with the external provider.- Returns:
- a
String
-
getDisplayName
Gets the displayName property value. Display name for the external MFA. This name is shown to users during sign-in.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethodConfiguration- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getIncludeTargets
Gets the includeTargets property value. A collection of groups that are enabled to use an authentication method as part of an authentication method policy in Microsoft Entra ID.- Returns:
- a
List<AuthenticationMethodTarget>
-
getOpenIdConnectSetting
Gets the openIdConnectSetting property value. The openIdConnectSetting property- Returns:
- a
OpenIdConnectSetting
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethodConfiguration- Parameters:
writer- Serialization writer to use to serialize this model
-
setAppId
Sets the appId property value. appId for the app registration in Microsoft Entra ID representing the integration with the external provider.- Parameters:
value- Value to set for the appId property.
-
setDisplayName
Sets the displayName property value. Display name for the external MFA. This name is shown to users during sign-in.- Parameters:
value- Value to set for the displayName property.
-
setIncludeTargets
Sets the includeTargets property value. A collection of groups that are enabled to use an authentication method as part of an authentication method policy in Microsoft Entra ID.- Parameters:
value- Value to set for the includeTargets property.
-
setOpenIdConnectSetting
Sets the openIdConnectSetting property value. The openIdConnectSetting property- Parameters:
value- Value to set for the openIdConnectSetting property.
-