Package com.microsoft.graph.models
Class Fido2AuthenticationMethodConfiguration
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethodConfiguration
com.microsoft.graph.models.Fido2AuthenticationMethodConfiguration
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class Fido2AuthenticationMethodConfiguration
extends AuthenticationMethodConfiguration
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newFido2AuthenticationMethodConfigurationand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptioncreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the defaultPasskeyProfile property value.The deserialization information for the current modelGets the includeTargets property value.Gets the isAttestationEnforced property value.Gets the isSelfServiceRegistrationAllowed property value.Gets the keyRestrictions property value.Gets the passkeyProfiles property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetDefaultPasskeyProfile(String value) Sets the defaultPasskeyProfile property value.voidSets the includeTargets property value.voidsetIsAttestationEnforced(Boolean value) Sets the isAttestationEnforced property value.voidSets the isSelfServiceRegistrationAllowed property value.voidSets the keyRestrictions property value.voidsetPasskeyProfiles(List<PasskeyProfile> value) Sets the passkeyProfiles property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethodConfiguration
getExcludeTargets, getState, setExcludeTargets, setStateMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
Fido2AuthenticationMethodConfiguration
public Fido2AuthenticationMethodConfiguration()Instantiates a newFido2AuthenticationMethodConfigurationand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static Fido2AuthenticationMethodConfiguration createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
Fido2AuthenticationMethodConfiguration
-
getDefaultPasskeyProfile
Gets the defaultPasskeyProfile property value. The non-deletable baseline passkey profile, within the passkey profile collection. It's automatically created when migrating to passkey profiles and initially mirrors the tenant's legacy global passkey (FIDO2) authentication methods policy settings.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethodConfiguration- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getIncludeTargets
Gets the includeTargets property value. A collection of groups that are enabled to use the authentication method.- Returns:
- a
List<PasskeyAuthenticationMethodTarget>
-
getIsAttestationEnforced
Gets the isAttestationEnforced property value. Determines whether attestation must be enforced for passkey (FIDO2) registration. This property is deprecated and will be removed in October 2027. Use passkeyProfiles property.- Returns:
- a
Boolean
-
getIsSelfServiceRegistrationAllowed
Gets the isSelfServiceRegistrationAllowed property value. Determines if users can register new passkeys (FIDO2).- Returns:
- a
Boolean
-
getKeyRestrictions
Gets the keyRestrictions property value. Controls whether key restrictions are enforced on passkeys (FIDO2), either allowing or disallowing certain key types as defined by Authenticator Attestation GUID (AAGUID), an identifier that indicates the type (for example, make and model) of the authenticator. This property is deprecated and will be removed in October 2027. Use the passkeyProfiles property.- Returns:
- a
Fido2KeyRestrictions
-
getPasskeyProfiles
Gets the passkeyProfiles property value. A collection of configuration profiles that control the registration of and authentication with passkeys (FIDO2).- Returns:
- a
List<PasskeyProfile>
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethodConfiguration- Parameters:
writer- Serialization writer to use to serialize this model
-
setDefaultPasskeyProfile
Sets the defaultPasskeyProfile property value. The non-deletable baseline passkey profile, within the passkey profile collection. It's automatically created when migrating to passkey profiles and initially mirrors the tenant's legacy global passkey (FIDO2) authentication methods policy settings.- Parameters:
value- Value to set for the defaultPasskeyProfile property.
-
setIncludeTargets
Sets the includeTargets property value. A collection of groups that are enabled to use the authentication method.- Parameters:
value- Value to set for the includeTargets property.
-
setIsAttestationEnforced
Sets the isAttestationEnforced property value. Determines whether attestation must be enforced for passkey (FIDO2) registration. This property is deprecated and will be removed in October 2027. Use passkeyProfiles property.- Parameters:
value- Value to set for the isAttestationEnforced property.
-
setIsSelfServiceRegistrationAllowed
Sets the isSelfServiceRegistrationAllowed property value. Determines if users can register new passkeys (FIDO2).- Parameters:
value- Value to set for the isSelfServiceRegistrationAllowed property.
-
setKeyRestrictions
Sets the keyRestrictions property value. Controls whether key restrictions are enforced on passkeys (FIDO2), either allowing or disallowing certain key types as defined by Authenticator Attestation GUID (AAGUID), an identifier that indicates the type (for example, make and model) of the authenticator. This property is deprecated and will be removed in October 2027. Use the passkeyProfiles property.- Parameters:
value- Value to set for the keyRestrictions property.
-
setPasskeyProfiles
Sets the passkeyProfiles property value. A collection of configuration profiles that control the registration of and authentication with passkeys (FIDO2).- Parameters:
value- Value to set for the passkeyProfiles property.
-