Package com.microsoft.graph.models
Class FileStorage
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.FileStorage
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class FileStorage
extends Entity
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic FileStoragecreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the containers property value.Gets the containerTypeRegistrations property value.Gets the containerTypes property value.Gets the deletedContainers property value.The deserialization information for the current modelvoidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetContainers(List<FileStorageContainer> value) Sets the containers property value.voidSets the containerTypeRegistrations property value.voidSets the containerTypes property value.voidSets the deletedContainers property value.Methods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
FileStorage
public FileStorage()Instantiates a newFileStorageand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static FileStorage createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
FileStorage
-
getContainers
Gets the containers property value. The collection of active fileStorageContainer resources.- Returns:
- a
List<FileStorageContainer>
-
getContainerTypeRegistrations
Gets the containerTypeRegistrations property value. The collection of fileStorageContainerTypeRegistration resources.- Returns:
- a
List<FileStorageContainerTypeRegistration>
-
getContainerTypes
Gets the containerTypes property value. The collection of fileStorageContainerType resources.- Returns:
- a
List<FileStorageContainerType>
-
getDeletedContainers
Gets the deletedContainers property value. The collection of deleted fileStorageContainer resources.- Returns:
- a
List<FileStorageContainer>
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classEntity- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object -
setContainers
Sets the containers property value. The collection of active fileStorageContainer resources.- Parameters:
value- Value to set for the containers property.
-
setContainerTypeRegistrations
public void setContainerTypeRegistrations(@Nullable List<FileStorageContainerTypeRegistration> value) Sets the containerTypeRegistrations property value. The collection of fileStorageContainerTypeRegistration resources.- Parameters:
value- Value to set for the containerTypeRegistrations property.
-
setContainerTypes
Sets the containerTypes property value. The collection of fileStorageContainerType resources.- Parameters:
value- Value to set for the containerTypes property.
-
setDeletedContainers
Sets the deletedContainers property value. The collection of deleted fileStorageContainer resources.- Parameters:
value- Value to set for the deletedContainers property.
-