Package com.microsoft.graph.models
Enum Class MonitorRunStatus
- All Implemented Interfaces:
com.microsoft.kiota.serialization.ValuedEnum,Serializable,Comparable<MonitorRunStatus>,Constable
@Generated("com.microsoft.kiota")
public enum MonitorRunStatus
extends Enum<MonitorRunStatus>
implements com.microsoft.kiota.serialization.ValuedEnum
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionA marker value for members added after the release of this API. -
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionstatic MonitorRunStatusgetValue()static MonitorRunStatusReturns the enum constant of this class with the specified name.static MonitorRunStatus[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
Successful
-
PartiallySuccessful
-
Failed
-
UnknownFutureValue
A marker value for members added after the release of this API.
-
-
Field Details
-
value
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
- Specified by:
getValuein interfacecom.microsoft.kiota.serialization.ValuedEnum
-
forValue
-