Package com.microsoft.graph.models
Class OpenIdConnectSetting
java.lang.Object
com.microsoft.graph.models.OpenIdConnectSetting
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class OpenIdConnectSetting
extends Object
implements com.microsoft.kiota.serialization.AdditionalDataHolder, com.microsoft.kiota.store.BackedModel, com.microsoft.kiota.serialization.Parsable
-
Field Summary
FieldsModifier and TypeFieldDescriptionprotected com.microsoft.kiota.store.BackingStoreStores model information. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic OpenIdConnectSettingcreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the AdditionalData property value.com.microsoft.kiota.store.BackingStoreGets the backingStore property value.Gets the clientId property value.Gets the discoveryUrl property value.The deserialization information for the current modelGets the @odata.type property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetAdditionalData(Map<String, Object> value) Sets the AdditionalData property value.voidsetBackingStore(com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value.voidsetClientId(String value) Sets the clientId property value.voidsetDiscoveryUrl(String value) Sets the discoveryUrl property value.voidsetOdataType(String value) Sets the @odata.type property value.
-
Field Details
-
backingStore
@Nonnull protected com.microsoft.kiota.store.BackingStore backingStoreStores model information.
-
-
Constructor Details
-
OpenIdConnectSetting
public OpenIdConnectSetting()Instantiates a newOpenIdConnectSettingand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static OpenIdConnectSetting createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
OpenIdConnectSetting
-
getAdditionalData
Gets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. -
getBackingStore
@Nonnull public com.microsoft.kiota.store.BackingStore getBackingStore()Gets the backingStore property value. Stores model information.- Specified by:
getBackingStorein interfacecom.microsoft.kiota.store.BackedModel- Returns:
- a
BackingStore
-
getClientId
Gets the clientId property value. The Microsoft Entra ID's client ID as generated by the provider or admin to identify Microsoft Entra ID. In OIDC parlance, this is the client_id that external identity provider assigns to Microsoft Entra ID, which is also a recipient of a token from the external identity provider.- Returns:
- a
String
-
getDiscoveryUrl
Gets the discoveryUrl property value. The host URL of the external identity provider's OIDC discovery endpoint. This endpoint must support the OIDC discovery process.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model -
getOdataType
Gets the @odata.type property value. The OdataType property- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Parameters:
writer- Serialization writer to use to serialize this model
-
setAdditionalData
Sets the AdditionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.- Parameters:
value- Value to set for the AdditionalData property.
-
setBackingStore
public void setBackingStore(@Nonnull com.microsoft.kiota.store.BackingStore value) Sets the backingStore property value. Stores model information.- Parameters:
value- Value to set for the backingStore property.
-
setClientId
Sets the clientId property value. The Microsoft Entra ID's client ID as generated by the provider or admin to identify Microsoft Entra ID. In OIDC parlance, this is the client_id that external identity provider assigns to Microsoft Entra ID, which is also a recipient of a token from the external identity provider.- Parameters:
value- Value to set for the clientId property.
-
setDiscoveryUrl
Sets the discoveryUrl property value. The host URL of the external identity provider's OIDC discovery endpoint. This endpoint must support the OIDC discovery process.- Parameters:
value- Value to set for the discoveryUrl property.
-
setOdataType
Sets the @odata.type property value. The OdataType property- Parameters:
value- Value to set for the @odata.type property.
-