Package com.microsoft.graph.models
Class ProfileSource
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.ProfileSource
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class ProfileSource
extends Entity
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ProfileSourcecreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the displayName property value.The deserialization information for the current modelgetKind()Gets the kind property value.Gets the localizations property value.Gets the sourceId property value.Gets the webUrl property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetDisplayName(String value) Sets the displayName property value.voidSets the kind property value.voidSets the localizations property value.voidsetSourceId(String value) Sets the sourceId property value.voidSets the webUrl property value.Methods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
ProfileSource
public ProfileSource()Instantiates a newProfileSourceand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static ProfileSource createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
ProfileSource
-
getDisplayName
Gets the displayName property value. Name of the profile source intended to inform users about the profile source name.- Returns:
- a
String
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classEntity- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getKind
Gets the kind property value. Type of the profile source.- Returns:
- a
String
-
getLocalizations
Gets the localizations property value. Alternative localized labels specified by an administrator.- Returns:
- a
List<ProfileSourceLocalization>
-
getSourceId
Gets the sourceId property value. Profile source identifier used as an alternate key.- Returns:
- a
String
-
getWebUrl
Gets the webUrl property value. Web URL of the profile source that directs users to the page view of the profile data.- Returns:
- a
String
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object -
setDisplayName
Sets the displayName property value. Name of the profile source intended to inform users about the profile source name.- Parameters:
value- Value to set for the displayName property.
-
setKind
Sets the kind property value. Type of the profile source.- Parameters:
value- Value to set for the kind property.
-
setLocalizations
Sets the localizations property value. Alternative localized labels specified by an administrator.- Parameters:
value- Value to set for the localizations property.
-
setSourceId
Sets the sourceId property value. Profile source identifier used as an alternate key.- Parameters:
value- Value to set for the sourceId property.
-
setWebUrl
Sets the webUrl property value. Web URL of the profile source that directs users to the page view of the profile data.- Parameters:
value- Value to set for the webUrl property.
-