Package com.microsoft.graph.models
Class QrCode
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.QrCode
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class QrCode
extends Entity
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic QrCodecreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueGets the createdDateTime property value.Gets the expireDateTime property value.The deserialization information for the current modelgetImage()Gets the image property value.Gets the lastUsedDateTime property value.Gets the startDateTime property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidsetCreatedDateTime(OffsetDateTime value) Sets the createdDateTime property value.voidsetExpireDateTime(OffsetDateTime value) Sets the expireDateTime property value.voidsetImage(QrCodeImageDetails value) Sets the image property value.voidSets the lastUsedDateTime property value.voidsetStartDateTime(OffsetDateTime value) Sets the startDateTime property value.Methods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
QrCode
public QrCode()Instantiates a newQrCodeand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static QrCode createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
QrCode
-
getCreatedDateTime
Gets the createdDateTime property value. The date and time when the QR code was created. Read-only.- Returns:
- a
OffsetDateTime
-
getExpireDateTime
Gets the expireDateTime property value. The date and time when the QR code expires. For standard QR codes, the lifetime is in days with a maximum of 395 days (13 months) and a default of 365 days. For temporary QR codes, the lifetime must be between 1-12 hours. The expireDateTime can be edited for standard QR codes but not for temporary QR codes.- Returns:
- a
OffsetDateTime
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classEntity- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getImage
Gets the image property value. The QR code image data. This property is only returned at the time of creating or resetting the QR code because the private key isn't stored on the server.- Returns:
- a
QrCodeImageDetails
-
getLastUsedDateTime
Gets the lastUsedDateTime property value. The date and time when the QR code was last successfully used for authentication. Read-only.- Returns:
- a
OffsetDateTime
-
getStartDateTime
Gets the startDateTime property value. The date and time when the QR code becomes available for use.- Returns:
- a
OffsetDateTime
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object -
setCreatedDateTime
Sets the createdDateTime property value. The date and time when the QR code was created. Read-only.- Parameters:
value- Value to set for the createdDateTime property.
-
setExpireDateTime
Sets the expireDateTime property value. The date and time when the QR code expires. For standard QR codes, the lifetime is in days with a maximum of 395 days (13 months) and a default of 365 days. For temporary QR codes, the lifetime must be between 1-12 hours. The expireDateTime can be edited for standard QR codes but not for temporary QR codes.- Parameters:
value- Value to set for the expireDateTime property.
-
setImage
Sets the image property value. The QR code image data. This property is only returned at the time of creating or resetting the QR code because the private key isn't stored on the server.- Parameters:
value- Value to set for the image property.
-
setLastUsedDateTime
Sets the lastUsedDateTime property value. The date and time when the QR code was last successfully used for authentication. Read-only.- Parameters:
value- Value to set for the lastUsedDateTime property.
-
setStartDateTime
Sets the startDateTime property value. The date and time when the QR code becomes available for use.- Parameters:
value- Value to set for the startDateTime property.
-