Package com.microsoft.graph.models
Class QrCodePinAuthenticationMethod
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethod
com.microsoft.graph.models.QrCodePinAuthenticationMethod
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class QrCodePinAuthenticationMethod
extends AuthenticationMethod
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newQrCodePinAuthenticationMethodand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptioncreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueThe deserialization information for the current modelgetPin()Gets the pin property value.Gets the standardQRCode property value.Gets the temporaryQRCode property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidSets the pin property value.voidsetStandardQRCode(QrCode value) Sets the standardQRCode property value.voidsetTemporaryQRCode(QrCode value) Sets the temporaryQRCode property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethod
getCreatedDateTime, setCreatedDateTimeMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
QrCodePinAuthenticationMethod
public QrCodePinAuthenticationMethod()Instantiates a newQrCodePinAuthenticationMethodand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static QrCodePinAuthenticationMethod createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
QrCodePinAuthenticationMethod
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethod- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getPin
Gets the pin property value. The PIN associated with this QR code authentication method.- Returns:
- a
QrPin
-
getStandardQRCode
Gets the standardQRCode property value. The standard (long-lived) QR code credential, typically printed on a user's badge.- Returns:
- a
QrCode
-
getTemporaryQRCode
Gets the temporaryQRCode property value. A temporary (short-lived) QR code credential, created when a user forgets their badge.- Returns:
- a
QrCode
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethod- Parameters:
writer- Serialization writer to use to serialize this model
-
setPin
Sets the pin property value. The PIN associated with this QR code authentication method.- Parameters:
value- Value to set for the pin property.
-
setStandardQRCode
Sets the standardQRCode property value. The standard (long-lived) QR code credential, typically printed on a user's badge.- Parameters:
value- Value to set for the standardQRCode property.
-
setTemporaryQRCode
Sets the temporaryQRCode property value. A temporary (short-lived) QR code credential, created when a user forgets their badge.- Parameters:
value- Value to set for the temporaryQRCode property.
-