Package com.microsoft.graph.models
Class QrCodePinAuthenticationMethodConfiguration
java.lang.Object
com.microsoft.graph.models.Entity
com.microsoft.graph.models.AuthenticationMethodConfiguration
com.microsoft.graph.models.QrCodePinAuthenticationMethodConfiguration
- All Implemented Interfaces:
com.microsoft.kiota.serialization.AdditionalDataHolder,com.microsoft.kiota.serialization.Parsable,com.microsoft.kiota.store.BackedModel
@Generated("com.microsoft.kiota")
public class QrCodePinAuthenticationMethodConfiguration
extends AuthenticationMethodConfiguration
implements com.microsoft.kiota.serialization.Parsable
-
Field Summary
Fields inherited from class com.microsoft.graph.models.Entity
backingStore -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newQrCodePinAuthenticationMethodConfigurationand sets the default values. -
Method Summary
Modifier and TypeMethodDescriptioncreateFromDiscriminatorValue(com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator valueThe deserialization information for the current modelGets the includeTargets property value.Gets the pinLength property value.Gets the standardQRCodeLifetimeInDays property value.voidserialize(com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current objectvoidSets the includeTargets property value.voidsetPinLength(Integer value) Sets the pinLength property value.voidSets the standardQRCodeLifetimeInDays property value.Methods inherited from class com.microsoft.graph.models.AuthenticationMethodConfiguration
getExcludeTargets, getState, setExcludeTargets, setStateMethods inherited from class com.microsoft.graph.models.Entity
getAdditionalData, getBackingStore, getId, getOdataType, setAdditionalData, setBackingStore, setId, setOdataType
-
Constructor Details
-
QrCodePinAuthenticationMethodConfiguration
public QrCodePinAuthenticationMethodConfiguration()Instantiates a newQrCodePinAuthenticationMethodConfigurationand sets the default values.
-
-
Method Details
-
createFromDiscriminatorValue
@Nonnull public static QrCodePinAuthenticationMethodConfiguration createFromDiscriminatorValue(@Nonnull com.microsoft.kiota.serialization.ParseNode parseNode) Creates a new instance of the appropriate class based on discriminator value- Parameters:
parseNode- The parse node to use to read the discriminator value and create the object- Returns:
- a
QrCodePinAuthenticationMethodConfiguration
-
getFieldDeserializers
@Nonnull public Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>> getFieldDeserializers()The deserialization information for the current model- Specified by:
getFieldDeserializersin interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
getFieldDeserializersin classAuthenticationMethodConfiguration- Returns:
- a
Map<String,Consumer<com.microsoft.kiota.serialization.ParseNode>>
-
getIncludeTargets
Gets the includeTargets property value. Groups of users that are included and enabled in the policy.- Returns:
- a
List<AuthenticationMethodTarget>
-
getPinLength
Gets the pinLength property value. The required length of the PIN. The minimum length is 8 digits (as per NIST standards), and the maximum is 20 digits.- Returns:
- a
Integer
-
getStandardQRCodeLifetimeInDays
Gets the standardQRCodeLifetimeInDays property value. The lifetime of standard QR codes in days. The default is 365 days and the maximum is 395 days (13 months). The minimum is 1 day.- Returns:
- a
Integer
-
serialize
public void serialize(@Nonnull com.microsoft.kiota.serialization.SerializationWriter writer) Serializes information the current object- Specified by:
serializein interfacecom.microsoft.kiota.serialization.Parsable- Overrides:
serializein classAuthenticationMethodConfiguration- Parameters:
writer- Serialization writer to use to serialize this model
-
setIncludeTargets
Sets the includeTargets property value. Groups of users that are included and enabled in the policy.- Parameters:
value- Value to set for the includeTargets property.
-
setPinLength
Sets the pinLength property value. The required length of the PIN. The minimum length is 8 digits (as per NIST standards), and the maximum is 20 digits.- Parameters:
value- Value to set for the pinLength property.
-
setStandardQRCodeLifetimeInDays
Sets the standardQRCodeLifetimeInDays property value. The lifetime of standard QR codes in days. The default is 365 days and the maximum is 395 days (13 months). The minimum is 1 day.- Parameters:
value- Value to set for the standardQRCodeLifetimeInDays property.
-